@@ -26,7 +26,7 @@ try {// Load root from config file.  Error if missing or unable to determine api
 
 var language = getURLParameter('lang');
 
-$().ready(function () {// Once ready, load templates.  
+$().ready(function () {// Once ready, load templates.
     templid = getURLParameter("templid");
     // Add addditional templates here.  Specify template id, the template file, and the location
     log ('template id is ', templid);
@@ -60,7 +60,7 @@ $().ready(function () {// Once ready, load templates.
                 $('#languageSelect').append('<li><a href="#" language="' + c + '">' + n + '</a></li>');
             }
         });
-        
+
         var user = getURLParameter('user');
         if (user !== null) {
             $('#Username').val(user);
@@ -392,7 +392,7 @@ function openreader(ldata, extra) {
         }
 
         $('#fromlist').html('<td class="tdname">' + i18n.t("From") +'</td><td><span class=\"oxlabelcontent\">' + prepHTML(getFrom(data)) + '</span></td>');
-        $('#subject').html(getSubject(data));
+        $('#subject').text(getSubject(data));
         $('#attdiv').remove();
         var readercont = $('#reader').contents().find('html');
         $('#reader').contents().find('html').html(getContent(data));
@@ -436,7 +436,7 @@ function openreader(ldata, extra) {
         // Make all name columns same size.  Check for largest
         window.setTimeout(function() {
             var max = 0;
-            $('.tdname').each(function(v, e) { 
+            $('.tdname').each(function(v, e) {
                 var w = $(e).width();
                 if (w > max) max = w;
             });
@@ -465,7 +465,7 @@ function openreader(ldata, extra) {
             fail();
             break;
         }
-        
+
     });
 
 }
@@ -559,7 +559,7 @@ function getFrom(data) {
         console.log(e);
         return ('');
     }
-    
+
 }
 
 function getSubject(data) {
@@ -649,7 +649,7 @@ function getauth () {
 }
 
 function getReplyData (data) {
-    
+
     var replyTo = JSON.parse(JSON.stringify(data.from));
     var replyAll = JSON.parse(JSON.stringify(data.from));
     var thisEmail = $('#Username').val();
@@ -686,7 +686,7 @@ function changeAttachments(attachments) {
     }
     $(attachments).val('');  // Clear file list
     drawAttachments();
-    
+
 }
 
 
@@ -753,7 +753,7 @@ function sendreply(data, all) {
 	}
 	else {
 	    content = $('.plaintexteditor').val();
-	} 
+	}
 
 	var mail = createJson (to, from, subject, content, data, format);
 	log (mail);
@@ -805,7 +805,7 @@ function sendreply(data, all) {
             } else {
                 $('#sendresult').html(i18n.t("An error occurred during sending the encrypted email reply"));
             }
-            
+
             $('#sending').hide();
         }
       });
@@ -829,7 +829,7 @@ function initReply (data, replyall) {
     $('.plaintexteditor').val('');
     attachlist = [];
     drawAttachments();
-    $('#rsubject').html(i18n.t("re") + ': ' + data.subject);
+    $('#rsubject').text(i18n.t("re") + ': ' + data.subject);
     var bm = tinyMCE.activeEditor.selection.getBookmark();
     tinyMCE.activeEditor.setContent(formatReply(data));
     tinyMCE.activeEditor.selection.moveToBookmark(bm);
@@ -956,13 +956,13 @@ function forgotPass() {
             $('#ForgotError').html(i18n.t("Failed to connect to server"));
 	    $('#ForgotError').show();
         });
-        
+
     } else {
         $('#EmailAddr').focus();
         $('#ForgotError').html(i18n.t("Please provide valid email address"));
         $('#ForgotError').show();
     }
-    
+
 }
 
 function forgotPass2() {
@@ -1025,7 +1025,7 @@ function convert (html, start) {
         var substring = html.substring(start);
         if (j > -1) {
             substring = html.substring(start, j);
-        } 
+        }
         var repl = '\n';
         if (i > -1) repl = '\n> ';
         var newstring = substring.replace(/\n/g, repl).replace(/<br[ \/]*>/gi, repl)
@@ -1189,7 +1189,7 @@ function updateSettings () {
     };
     settings.inline = inline;
     settings.direct = direct;
-    
+
     var json = {
             id : userid,
             cid : cid,
@@ -1236,7 +1236,7 @@ function downloadKeys() {
        if ($(v).is(':checked')) {
            var index = $(v).val();
            key = {
-                   username : username, 
+                   username : username,
                    index : index,
                    password : $('#pass' + index).val()
            }
@@ -1272,7 +1272,7 @@ function downloadKeys() {
         });
     }
 
-    
+
 }
 
 function logOut () {
@@ -1283,7 +1283,7 @@ function logOut () {
     .fail(function () {
         alert(i18n.t('Fail'));
     });
-    
+
 }
 
 function log (where, data) {
