@@ -18,15 +18,15 @@ import com.google.gson.JsonParser;
 import com.openexchange.guard.server.connectionPooling.HttpConnectionPoolService;
 
 public class OxConfiguration {
-	private static Logger logger = LoggerFactory.getLogger(OxConfiguration.class);
-	final static String templid = "com.openexchange.guard.templateID";
-	final static String fromEmail = "com.openexchange.guard.fromEmail";
-	final static String externalReader = "com.openexchange.guard.externalReaderURL";
-	final static String deleteDraft = "com.openexchange.mail.deleteDraftOnTransport";
-	final static String oxUI = "com.openexchange.guard.externalOxUI";
-	final static String secureReply = "com.openexchange.guard.secureReply";
-	final static String defaultReaderURL = "https://" + Config.externalReaderPath;
-	final static String defaultOxUI = Config.OXUrl;
+    private static Logger logger = LoggerFactory.getLogger(OxConfiguration.class);
+    final static String templid = "com.openexchange.guard.templateID";
+    final static String fromEmail = "com.openexchange.guard.fromEmail";
+    final static String externalReader = "com.openexchange.guard.externalReaderURL";
+    final static String deleteDraft = "com.openexchange.mail.deleteDraftOnTransport";
+    final static String oxUI = "com.openexchange.guard.externalOxUI";
+    final static String secureReply = "com.openexchange.guard.secureReply";
+    final static String defaultReaderURL = "https://" + Config.externalReaderPath;
+    final static String defaultOxUI = Config.OXUrl;
 
 
     private static JsonObject getOgRequest(String prop, int cid, int id, boolean required) throws Exception {
@@ -42,22 +42,22 @@ public class OxConfiguration {
         getRequest.addHeader("Authorization", "Basic " + Config.getBasicAuthenticationEncoding());
         CloseableHttpResponse response = httpClient.execute(getRequest, context);
         if (response.getStatusLine().getStatusCode() != 200) {
-        	try {
-        		EntityUtils.consume(response.getEntity());
-        		getRequest.releaseConnection();
-        		response.close();
-        	} catch (Exception e2) {
-        		logger.error("unable to close http stream after error", e2);
-        	}
-        	if (response.getStatusLine().getStatusCode() == 404) {
-        		if (required) {
-        			logger.error("Unable to retrieve " + prop + " from backend, is guard.properties on OX backend setup properly?");
-        		} else {
-        			logger.info("Unable to retrieve " + prop + " from backend.  Consider adding to backend guard.properties file.");
-        		}
-        		return(null);
-        	}
-        	logger.error("Error getting " + prop + " from backend " + response.getStatusLine().getReasonPhrase());
+            try {
+                EntityUtils.consume(response.getEntity());
+                getRequest.releaseConnection();
+                response.close();
+            } catch (Exception e2) {
+                logger.error("unable to close http stream after error", e2);
+            }
+            if (response.getStatusLine().getStatusCode() == 404) {
+                if (required) {
+                    logger.error("Unable to retrieve " + prop + " from backend, is guard.properties on OX backend setup properly?");
+                } else {
+                    //logger.info("Unable to retrieve " + prop + " from backend.  Consider adding to backend guard.properties file.");
+                }
+                return(null);
+            }
+            logger.error("Error getting " + prop + " from backend " + response.getStatusLine().getReasonPhrase());
             throw new Exception("Failed : HTTP error code : " + response.getStatusLine().getStatusCode());
         }
         result = getJson(response);
@@ -91,47 +91,47 @@ public class OxConfiguration {
     }
 
     public static int getTemplateId (int cid, int id) {
-    	try {
-    		if (cid < 0) {
+        try {
+            if (cid < 0) {
                 return (0);
             }
-    		JsonObject tjson = getProp(templid, cid, id, true);
-    		if (tjson == null) {
+            JsonObject tjson = getProp(templid, cid, id, true);
+            if (tjson == null) {
                 return(0);
             }
-    		if (tjson.has(templid)) {
-    			return (tjson.get(templid).getAsInt());
-    		} else {
+            if (tjson.has(templid)) {
+                return (tjson.get(templid).getAsInt());
+            } else {
                 return (0);
             }
-    	} catch (Exception ex) {
-    		logger.error("Error getting custom template ID ", ex);
-    		return (0);
-    	}
+        } catch (Exception ex) {
+            logger.error("Error getting custom template ID ", ex);
+            return (0);
+        }
     }
 
     public static String getFromEmail (int id, int cid) {
-    	try {
-    		if (cid == 0) {
+        try {
+            if (cid == 0) {
                 return (null);
             }
-    		if (cid < 0) {
-    			cid = -cid;
-    			id = -1;
-    		}
-    		JsonObject tjson = getProp(fromEmail, cid, id, false);
-    		if (tjson == null) {
+            if (cid < 0) {
+                cid = -cid;
+                id = -1;
+            }
+            JsonObject tjson = getProp(fromEmail, cid, id, false);
+            if (tjson == null) {
                 return(null);
             }
-    		if (tjson.has(fromEmail)) {
-    			return (tjson.get(fromEmail).getAsString());
-    		} else {
+            if (tjson.has(fromEmail)) {
+                return (tjson.get(fromEmail).getAsString());
+            } else {
                 return (null);
             }
-    	} catch (Exception ex) {
-    		logger.error("Error getting from Email address for password template ", ex);
-    		return (null);
-    	}
+        } catch (Exception ex) {
+            logger.error("Error getting from Email address for password template ", ex);
+            return (null);
+        }
     }
 
     public static String getExternalReaderURL (int id, int cid) {
@@ -191,7 +191,7 @@ public class OxConfiguration {
     public static boolean deleteDraft (int id, int cid) {
         return (getBoolResult (id, cid, deleteDraft, false));
     }
-    
+
     /**
      * Return if user configured for all replies to be secure
      * @param id
@@ -201,7 +201,7 @@ public class OxConfiguration {
     public static boolean secureReply (int id, int cid) {
         return (getBoolResult(id, cid, secureReply, true));
     }
-    
+
     private static boolean getBoolResult (int id, int cid, String request, boolean defaultVal) {
         try {
             if (cid == 0) {
