@@ -50,6 +50,9 @@
 package com.openexchange.guard.database;
 
 import java.util.ArrayList;
+import java.util.Iterator;
+import org.bouncycastle.openpgp.PGPPublicKey;
+import org.bouncycastle.openpgp.PGPPublicKeyRing;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.google.gson.JsonObject;
@@ -206,7 +209,7 @@ public class GetPubKey {
 
 
         if (!remote) {
-            result = PgpKeyLookup.getRemoteKeys(email);
+            result = PgpKeyLookup.getRemoteKeys(email, from);
             if (result != null) {
                 return(result);
             }
@@ -271,7 +274,7 @@ public class GetPubKey {
             result.settings = key.settings;
             result.pgpring = key.pubring;
             if (result.pgpring != null) {
-                result.expired = PgpKeys.isExpired(result.pgpring.getPublicKey());
+                result.expired = PgpKeys.checkAllExpired(result.pgpring);
                 result.pgp = true;
             }
             result.lang = key.language;
