@@ -54,42 +54,39 @@ import java.io.IOException;
 import java.io.InputStreamReader;
 import java.io.UnsupportedEncodingException;
 import java.net.URLEncoder;
-
 import org.apache.http.HttpResponse;
 import org.apache.http.client.methods.CloseableHttpResponse;
 import org.apache.http.client.methods.HttpGet;
 import org.apache.http.client.protocol.HttpClientContext;
 import org.apache.http.impl.client.CloseableHttpClient;
-import org.apache.http.impl.client.DefaultHttpClient;
-import org.apache.http.impl.client.HttpClientBuilder;
 import org.apache.http.protocol.HttpContext;
 import org.apache.http.util.EntityUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-
 import com.google.gson.JsonObject;
 import com.google.gson.JsonParser;
 import com.openexchange.guard.config.Config;
-import com.openexchange.guard.server.OxDbConn;
-import com.openexchange.guard.validator.Normalizer;
+import com.openexchange.guard.server.connectionPooling.HttpConnectionPoolService;
 
 public class Utilities {
 
 	private static Logger logger = LoggerFactory.getLogger(Utilities.class);
-    
+
 	private JsonObject getOgRequest(String unit, String action, String parameters) throws Exception {
 		String url = "http" + (Config.backend_ssl ? "s" : "") + "://" + Config.getOxBackend() + ":" + Config.ox_backend_port + "/preliminary/utilities/" + unit + "/v1/" + action + "/" + parameters;
 		return(getOgRequest(url));
 	}
-	
+
     private JsonObject getOgRequest(String url) throws Exception {
 
         JsonObject result = null;
-        CloseableHttpClient httpClient = OxDbConn.httpClient;
+        //CloseableHttpClient httpClient = OxDbConn.httpClient;
+        CloseableHttpClient httpClient = HttpConnectionPoolService.getClient();
         HttpContext context = HttpClientContext.create();
         HttpGet getRequest = new HttpGet(url);
         getRequest.addHeader("accept", "application/json");
         getRequest.addHeader("Authorization", "Basic " + Config.getBasicAuthenticationEncoding());
+        getRequest.setHeader("User-Agent", Config.apiUserAgent);
         CloseableHttpResponse response = httpClient.execute(getRequest, context);
         if (response.getStatusLine().getStatusCode() != 200) {
         	try {
@@ -108,7 +105,7 @@ public class Utilities {
         		}
         	}
         	logger.error("Error getting user data from backend " + response.getStatusLine().getReasonPhrase());
-        	
+
             throw new Exception("Failed : HTTP error code : " + response.getStatusLine().getStatusCode());
         }
         result = getJson(response);
@@ -118,11 +115,11 @@ public class Utilities {
         return (result);
 
     }
-    
+
 
     /**
      * Format response into a JSON object
-     * 
+     *
      * @param response
      * @return
      * @throws UnsupportedEncodingException
@@ -143,7 +140,9 @@ public class Utilities {
     	if (Config.mailResolverUrl == null) {
     		return (getOgRequest("mailResolver", "resolve", email));
     	} // Otherwise, use the assigned URL, adding the email address to the end
-    	else return (getOgRequest(Config.mailResolverUrl + email));
+ else {
+            return (getOgRequest(Config.mailResolverUrl + email));
+        }
     }
 
 }
