@@ -87,7 +87,7 @@ public class OffsiteKeys {
         String email = "";
         boolean success = true;
         EncrLib encr = new EncrLib();
-        String command = "SELECT * from og_content_keys WHERE CID = ? AND UserId = ?";
+        String command = "SELECT ItemId, ContentKey from og_content_keys WHERE CID = ? AND UserId = ?";
         DbCommand com = new DbCommand(command);
         com.addVariables(cid);
         com.addVariables(userid);
