@@ -63,7 +63,6 @@ import java.security.spec.InvalidKeySpecException;
 import java.security.spec.RSAPrivateCrtKeySpec;
 import java.security.spec.RSAPublicKeySpec;
 import java.sql.SQLException;
-
 import org.bouncycastle.crypto.AsymmetricCipherKeyPair;
 import org.bouncycastle.crypto.generators.RSAKeyPairGenerator;
 import org.bouncycastle.crypto.params.RSAKeyGenerationParameters;
@@ -72,17 +71,17 @@ import org.bouncycastle.crypto.params.RSAPrivateCrtKeyParameters;
 import org.bouncycastle.openssl.PEMWriter;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-
 import com.openexchange.guard.config.Config;
-import com.openexchange.guard.database.DbCommand;
-import com.openexchange.guard.database.DbQuery;
+import com.openexchange.guard.database.keyCache.KeyCacheStorage;
+import com.openexchange.guard.database.keyCache.RestDbKeyCacheStorage;
 
 public class PopulateRSA implements Runnable  {
-	
+
 	private static Logger logger = LoggerFactory.getLogger(PopulateRSA.class);
-	
+
     public boolean running = true;
 
+    @Override
     public void run() {
     	if (Config.keyCacheCheckInterval == 0) {
     		logger.info("KeyCacheCheckInterval set to 0.  Exiting RSA cache generator");
@@ -93,23 +92,17 @@ public class PopulateRSA implements Runnable  {
             while (!Thread.currentThread().isInterrupted()) {
                 try {
 
-                    String command = "SELECT COUNT(id) AS count FROM key_cache";
-                    DbCommand com = new DbCommand(command);
-                    DbQuery db = new DbQuery();
-                    db.readOG(com);
-                    if (db.next()) {
-                        int count = db.rs.getInt("count");
-                        if (count < Config.rsa_cache_count) {
-                            while (count < Config.rsa_cache_count) {
-                                count++;
-                                String newkey = genKeyPair();
-                                storekey(newkey);
-                            }
+                    //TODO: use a ServiceLocator or DI Container to resolve this
+                    KeyCacheStorage keyCacheStorage = new RestDbKeyCacheStorage();
+
+                    int count = keyCacheStorage.getCount();
+                    if (count < Config.rsa_cache_count) {
+                        while (count < Config.rsa_cache_count) {
+                            count++;
+                            String newkey = genKeyPair();
+                            storekey(newkey);
                         }
-                    } else {
-                    	logger.error("Unable to access key_cache table.  Check database permissions");
                     }
-                    db.close();
                 } catch (Exception e) {
                     logger.error("Unable to access key_cache table.  Check database permissions", e);
                 }
@@ -117,25 +110,24 @@ public class PopulateRSA implements Runnable  {
             }
         } catch (Exception ex) {
             logger.info("Keygenerator shutdown");;
-            
+
         }
     }
 
     /**
      * Store RSA key PEM for future use.  Encrypt with Config.rpass
-     * @param data
-     * @throws SQLException
+     * @param keyAsc the ascii armored to to save
+     * @throws SQLException due an error
      */
-    private void storekey(String data) throws SQLException {
+    private void storekey(String keyAsc) throws SQLException {
         try {
+            //encrypting the key for storing it in the DB
             EncrLib encr = new EncrLib();
-            data = encr.encryptAES(data, Config.rpass, "key", Config.AESKeyLen);
-            String command = "INSERT INTO key_cache VALUES (NULL, ?)";
-            DbCommand com = new DbCommand(command);
-            com.addVariables(data);
-            DbQuery db = new DbQuery();
-            db.writeOxGuard(com);
-            db.close();
+            keyAsc = encr.encryptAES(keyAsc, Config.rpass, "key", Config.AESKeyLen);
+
+            //TODO: use service locator / DI container for resolving
+            KeyCacheStorage keyCacheStorage = new RestDbKeyCacheStorage();
+            keyCacheStorage.insert(keyAsc);
         } catch (Exception ex) {
             logger.error("Error while storing key", ex);
         }
@@ -155,23 +147,23 @@ public class PopulateRSA implements Runnable  {
          AsymmetricCipherKeyPair kp = kpgen.generateKeyPair();
          RSAPrivateCrtKeyParameters rsapckp =
                  (RSAPrivateCrtKeyParameters) kp.getPrivate();
-      
+
          RSAKeyParameters rsakp = (RSAKeyParameters) kp.getPublic();
-      
+
          KeyFactory fact = KeyFactory.getInstance("RSA", "BC");
-      
+
          RSAPrivateCrtKeySpec prvKeySpecs =
                  new RSAPrivateCrtKeySpec(rsapckp.getModulus(),
                  rsapckp.getPublicExponent(), rsapckp.getExponent(),
                  rsapckp.getP(), rsapckp.getQ(), rsapckp.getDP(),
                  rsapckp.getDQ(), rsapckp.getQInv());
-      
+
          PrivateKey privateKey = fact.generatePrivate(prvKeySpecs);
-      
+
          RSAPublicKeySpec pubKeySpecs =
                  new RSAPublicKeySpec(rsakp.getModulus(), rsakp.getExponent());
          PublicKey publicKey = fact.generatePublic(pubKeySpecs);
-      
+
          KeyPair newkp = new KeyPair(publicKey, privateKey);
          // Export
          StringWriter writer = new StringWriter();
@@ -181,7 +173,7 @@ public class PopulateRSA implements Runnable  {
          wr.close();
          logger.debug("Key generated for cache");
          return (writer.toString());
-    	
+
     }
 
 
