@@ -51,8 +51,6 @@ package com.openexchange.guard.file;
 
 import java.io.ByteArrayInputStream;
 import java.io.StringWriter;
-
-import javax.servlet.http.HttpServletRequest;
 import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
 import javax.xml.transform.Transformer;
@@ -60,13 +58,11 @@ import javax.xml.transform.TransformerException;
 import javax.xml.transform.TransformerFactory;
 import javax.xml.transform.dom.DOMSource;
 import javax.xml.transform.stream.StreamResult;
-
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.w3c.dom.Element;
 import org.w3c.dom.NodeList;
 import org.xml.sax.InputSource;
-
 import com.google.gson.JsonArray;
 import com.google.gson.JsonObject;
 import com.openexchange.guard.database.Access;
@@ -78,14 +74,12 @@ import com.openexchange.guard.database.RetrievedItem;
 import com.openexchange.guard.encr.Crypto;
 import com.openexchange.guard.encr.EncrLib;
 import com.openexchange.guard.encr.GuardKeys;
-import com.openexchange.guard.encr.RSAGen;
 import com.openexchange.guard.ox.InterOx;
-import com.openexchange.guard.server.OxCookie;
 
 public class Fileshare {
 
 	private static Logger logger = LoggerFactory.getLogger(Fileshare.class);
-	
+
     public String shareItem(String itemId, String name, String email, String contentKey, GuardKeys owner) {
         try {
             Access acc = new Access();
@@ -95,25 +89,16 @@ public class Fileshare {
                 GetPubKey gk = new GetPubKey();
                 RecipKey rkey = gk.getPubKey(email, owner.userid, owner.contextid, owner.email, true, true);
                 if (rkey == null)
+                 {
                     return (null); // not found
-                if (rkey.pubkey == null) 
-                	return (null); // unable
+                }
+                if (rkey.pubkey == null)
+                 {
+                    return (null); // unable
+                }
                 if (rkey.cid != owner.contextid) {// For now, limit to same contextid.  Work on remote later
                 	return ("nsc");
                 }
-                if (rkey.remote) {
-                    RetrievedItem file = acc.getItemID(itemId, owner.userid, owner.contextid);
-                    EncrLib encr = new EncrLib();
-                    String encrcontentkey = encr.encryptRSA(contentKey, rkey.pubkey);
-                    InterOx iox = new InterOx();
-                    iox.sendItem(email, itemId, encrcontentkey, file.expiration, file.Type, file.XML, file.salt);
-                    if (addShare(itemId, owner.userid, owner.contextid, name, email, rkey.userid, rkey.cid, true)) {
-                        String returndata = "{\"i\":" + rkey.userid + ", \"c\": " + rkey.cid + ", \"r\": \"Y\"}";
-                        return (returndata);
-                    } else
-                        return (null);
-
-                }
                 keys = new GuardKeys(rkey);
             }
             if (keys.contextid != owner.contextid) {
