@@ -310,6 +310,8 @@ public class Incoming {
 	                // Search for attachments that reference a draft email, and aren't actually supplied.
 	                data = getDraftAttachments (data, attachments, request, cookie, userid, cid);
 
+	                data = getForwardedAttachments (data, attachments, request, cookie, userid, cid);
+
 	                addVcard (data, attachments, request, cookie, userid, cid);
 
 	                //Adding the sender's public key if at least one recipient is a non guest, remote user
@@ -509,6 +511,62 @@ public class Incoming {
 
 	    }
 
+	    /**
+	     * Get Attachments from msgref referenced object
+	     * @param data
+	     * @param attachments
+	     * @param request
+	     * @param ck
+	     * @param userid
+	     * @param cid
+	     * @return
+	     */
+	    public JsonObject getForwardedAttachments (JsonObject data, ArrayList<Attachment> attachments, HttpServletRequest request, OxCookie ck, int userid, int cid) {
+	        try {
+	            String msgref = data.has("msgref") ? data.get("msgref").getAsString() : null;
+	            if (msgref == null) return (data);
+	            JsonArray attachmentsArray = data.get("attachments").getAsJsonArray();
+	            JsonArray newAttachments = new JsonArray();
+	            for (int i = 0; i < attachmentsArray.size(); i++) {
+	                boolean pulled = false;
+	                JsonObject attachment = attachmentsArray.get(i).getAsJsonObject();
+	                if (attachment.has("disp") && attachment.get("disp").getAsString().equals("attachment")) {
+	                    if (attachment.has("filename")) {
+	                        String filename = attachment.get("filename").getAsString();
+	                        boolean found = false;
+	                        // First, search through our already loaded attachments and make sure wasn't sent with post
+	                        for (Attachment att : attachments) {
+	                            if (att.filename.equals(filename)) found = true;
+	                        }
+	                        if (!found) {  // If not, pull from the msgref
+	                            String id = attachment.get("id").getAsString();
+	                            Api ap = new Api (ck, request);
+	                            int j = msgref.lastIndexOf("/");
+	                            String folder = msgref.substring(0,j);
+	                            String emailid = msgref.substring(j+1).trim();
+	                            Attachment attach = ap.getPlainAttachment(emailid, id, folder);
+	                            if (attach != null) {
+	                                attach.filename = attachment.get("filename").getAsString();
+	                                attach.type = attachment.get("content_type").getAsString();
+	                                attachments.add(attach);
+	                                pulled = true;
+	                            } else {
+	                                logger.error("Problem pulling attachment for msgref " + msgref);
+	                            }
+	                        }
+	                    }
+	                }
+	                if (!pulled) newAttachments.add(attachment);
+	            }
+	            // We need to remove the attachments from the JSON for the ones we pulled out, otherwise PGP Inline sends would double up, but we need it pulled for Guest/Mime
+	            data.remove("attachments");
+	            data.add("attachments", newAttachments);
+	        } catch (Exception e) {
+	            logger.error("Problem getting msgref attachments ", e);
+	        }
+	        return (data);
+	    }
+
 	    /**
 	     * Get attachments from draft email if any.  Looks for atmsgref for regular emails
 	     * @param data
