@@ -110,7 +110,7 @@ import com.openexchange.guard.util.JsonExtractor;
  * @author greg
  */
 public class Api {
-	private static Logger logger = LoggerFactory.getLogger(Api.class);
+    private static Logger logger = LoggerFactory.getLogger(Api.class);
 
     HttpContext httpContext = null;
 
@@ -169,7 +169,7 @@ public class Api {
      */
     public String login(String username, String password) {
         // httpClient = new DefaultHttpClient();
-    	//CloseableHttpClient httpClient = OxDbConn.httpClient;
+        //CloseableHttpClient httpClient = OxDbConn.httpClient;
         CloseableHttpClient httpClient = HttpConnectionPoolService.getCookielessClient();
         CookieStore cookieStore = new BasicCookieStore();
         httpContext = new BasicHttpContext();
@@ -210,8 +210,8 @@ public class Api {
 
         if (httpClient == null) {
             // httpClient = new DefaultHttpClient();
-        	//httpClient = OxDbConn.httpClient;
-        	httpClient = HttpConnectionPoolService.getCookielessClient();
+            //httpClient = OxDbConn.httpClient;
+            httpClient = HttpConnectionPoolService.getCookielessClient();
         }
 
         HttpGet getRequest = new HttpGet("http" + (Config.backend_ssl ? "s" : "") + "://" + Config.getOxBackend() + ":" + Config.ox_backend_port + Config.OXBackendPath + params + "&session=" + session);
@@ -227,12 +227,12 @@ public class Api {
             response = httpClient.execute(getRequest, httpContext);
         }
         if (response.getStatusLine().getStatusCode() != 200) {
-        	try {
-        		response.close();
-        		getRequest.releaseConnection();
-        	} catch (Exception e2) {
-        		logger.error("unable to close failed connection at API getRequest", e2);
-        	}
+            try {
+                response.close();
+                getRequest.releaseConnection();
+            } catch (Exception e2) {
+                logger.error("unable to close failed connection at API getRequest", e2);
+            }
             throw new RuntimeException("Failed : HTTP error code : " + response.getStatusLine().getStatusCode() + " " + response.getStatusLine().getReasonPhrase());
         }
         return (response);
@@ -262,19 +262,33 @@ public class Api {
             response = httpClient.execute(putRequest, httpContext);
         }
         if (response.getStatusLine().getStatusCode() != 200) {
-        	try {
-        		response.close();
-        		putRequest.releaseConnection();
-        	} catch (Exception e2) {
-        		logger.error("unable to close failed connection at API putRequest", e2);
-        	}
+            try {
+                response.close();
+                putRequest.releaseConnection();
+            } catch (Exception e2) {
+                logger.error("unable to close failed connection at API putRequest", e2);
+            }
             throw new RuntimeException("Failed : HTTP error code : " + response.getStatusLine().getStatusCode() + " " + response.getStatusLine().getReasonPhrase());
         }
-        putRequest.releaseConnection();
+ //       putRequest.releaseConnection();
         return (response);
 
     }
 
+    private void consumeResponse (CloseableHttpResponse resp) {
+        try {
+            HttpEntity entity = resp.getEntity();
+            EntityUtils.consume(entity);
+        } catch (Exception ex) {
+            logger.error("error closing http response ", ex);
+        }
+        try {
+            resp.close();
+        } catch (IOException e) {
+            logger.error("error closing http response ", e);
+        }
+    }
+
     public JsonObject postRequest(String data, String params) throws ClientProtocolException, IOException {
 
         if (httpClient == null) {
@@ -297,12 +311,12 @@ public class Api {
         }
 
         if (response.getStatusLine().getStatusCode() != 200) {
-        	try {
-        		response.close();
-        		postRequest.releaseConnection();
-        	} catch (Exception e2) {
-        		logger.error("unable to close failed connection at API postRequest", e2);
-        	}
+            try {
+                response.close();
+                postRequest.releaseConnection();
+            } catch (Exception e2) {
+                logger.error("unable to close failed connection at API postRequest", e2);
+            }
             throw new RuntimeException("Failed : HTTP error code : " + response.getStatusLine().getStatusCode() + " " + response.getStatusLine().getReasonPhrase());
         }
         BufferedReader reader = new BufferedReader(new InputStreamReader(response.getEntity().getContent(), "UTF-8"));
@@ -439,7 +453,7 @@ public class Api {
             logger.error("Error sending mail", e);
 
         } catch (IOException e) {
-        	logger.error("Error sending mail", e);
+            logger.error("Error sending mail", e);
         }
         return (null);
     }
@@ -452,46 +466,46 @@ public class Api {
      * @throws UnsupportedEncodingException
      */
     public String sendMimeMail (String data, String folder) throws UnsupportedEncodingException {
-    	String params = "mail?action=new";
+        String params = "mail?action=new";
         params += "&session=" + session;
         if (folder != null) {
-        	params += "&folder=" + URLEncoder.encode(folder, "UTF-8");
-        	params += "&flags=32"; //Marks the email as "read" while putting it in the folder
+            params += "&folder=" + URLEncoder.encode(folder, "UTF-8");
+            params += "&flags=32"; //Marks the email as "read" while putting it in the folder
         } else {
             params += "&copy2Sent=false";
         }
         Gson gson = new GsonBuilder().disableHtmlEscaping().create();
 
         try {
-        	CloseableHttpResponse response = putRequest(params, data);
+            CloseableHttpResponse response = putRequest(params, data);
             HttpEntity ent = response.getEntity();
             String dat = EntityUtils.toString(ent);
-            response.close();
-        	return (dat);
+            consumeResponse (response);
+            return (dat);
         } catch (ClientProtocolException e) {
             logger.error("Error sending mail", e);
 
         } catch (IOException e) {
-        	logger.error("Error sending mail", e);
+            logger.error("Error sending mail", e);
         }
         return (null);
     }
 
     public JsonObject saveSentMail(JsonObject mail, ArrayList<Attachment> attachments, String sentfolder) {
-	        String params = "mail?action=new";
-	        try {
-				params += "&folder=" + URLEncoder.encode(sentfolder, "UTF-8") + "&session=" + session;
-			} catch (UnsupportedEncodingException e1) {
-				logger.error("Impossible, UTF-8 encoding failed");
-			}
-	        Gson gson = new Gson();
-	        try {
-	            return (multipartPost(gson.toJson(mail.getAsJsonObject("data")), params, attachments));
-	        } catch (ClientProtocolException e) {
-	        	logger.error("Error saving sent mail", e);
-	        } catch (IOException e) {
-	        	logger.error("IO error saving sent mail", e);
-	        }
+            String params = "mail?action=new";
+            try {
+                params += "&folder=" + URLEncoder.encode(sentfolder, "UTF-8") + "&session=" + session;
+            } catch (UnsupportedEncodingException e1) {
+                logger.error("Impossible, UTF-8 encoding failed");
+            }
+            Gson gson = new Gson();
+            try {
+                return (multipartPost(gson.toJson(mail.getAsJsonObject("data")), params, attachments));
+            } catch (ClientProtocolException e) {
+                logger.error("Error saving sent mail", e);
+            } catch (IOException e) {
+                logger.error("IO error saving sent mail", e);
+            }
         return (null);
     }
 
@@ -501,9 +515,9 @@ public class Api {
         try {
             return (multipartPost(gson.toJson(mail.getAsJsonObject("data")), params, attachments));
         } catch (ClientProtocolException e) {
-        	logger.error("Error saving sent mail", e);
+            logger.error("Error saving sent mail", e);
         } catch (IOException e) {
-        	logger.error("IO error saving sent mail", e);
+            logger.error("IO error saving sent mail", e);
         }
     return (null);
 }
@@ -516,9 +530,9 @@ public class Api {
         try {
             return (multipartPost(gson.toJson(mail.getAsJsonObject("data")), params, attachments));
         } catch (ClientProtocolException e) {
-        	logger.error("Error saving inbox", e);
+            logger.error("Error saving inbox", e);
         } catch (IOException e) {
-        	logger.error("Error saving inbox", e);
+            logger.error("Error saving inbox", e);
         }
         return (null);
     }
@@ -539,15 +553,15 @@ public class Api {
             return (item);
 
         } catch (IllegalStateException e) {
-        	logger.error("Error getting attachment", e);
+            logger.error("Error getting attachment", e);
         } catch (IOException e) {
-        	logger.error("IO error getting attachment", e);
+            logger.error("IO error getting attachment", e);
         }
         return (null);
     }
 
     public Attachment getPlainAttachment (String id, String attachment, String folder) throws UnsupportedEncodingException {
-    	long start = System.currentTimeMillis();
+        long start = System.currentTimeMillis();
         String params = "mail?action=attachment" + "&folder=" + URLEncoder.encode(folder, "UTF-8") + "&id=" + URLEncoder.encode(id, "UTF-8") + "&attachment=" + attachment;
         try {
             CloseableHttpResponse response = getResponse(params);
@@ -558,21 +572,21 @@ public class Api {
             return (att);
 
         } catch (IllegalStateException e) {
-        	logger.error("Error getting attachment", e);
+            logger.error("Error getting attachment", e);
         } catch (IOException e) {
-        	logger.error("IO error getting attachment", e);
+            logger.error("IO error getting attachment", e);
         }
         return (null);
     }
 
     public String getMime (String ref) throws UnsupportedEncodingException {
-    	int i = ref.lastIndexOf(("/"));
-    	if (i < -1) {
+        int i = ref.lastIndexOf(("/"));
+        if (i < -1) {
             return (null);
         }
-    	String folder = ref.substring(0, i);
-    	String id = ref.substring(i+1);
-    	return getMime(id, folder);
+        String folder = ref.substring(0, i);
+        String id = ref.substring(i+1);
+        return getMime(id, folder);
     }
 
     public String getMime(String id, String folder) throws UnsupportedEncodingException {
@@ -605,15 +619,15 @@ public class Api {
     }
 
     public int getContextId () {
-    	String params = "config/context_id?session=" + session;
-		try {
-			CloseableHttpResponse response = getResponse(params);
-			JsonObject data = Core.getJson(response);
+        String params = "config/context_id?session=" + session;
+        try {
+            CloseableHttpResponse response = getResponse(params);
+            JsonObject data = Core.getJson(response);
             return (data.get("data").getAsInt());
-		} catch (Exception ex) {
-			logger.error("Error getting contextId", ex);
+        } catch (Exception ex) {
+            logger.error("Error getting contextId", ex);
             return (0);
-		}
+        }
     }
 
     public String getFolder(int id) {
@@ -636,7 +650,7 @@ public class Api {
             CloseableHttpResponse response = putRequest(params, json);
             HttpEntity ent = response.getEntity();
             String data = EntityUtils.toString(ent);
-            response.close();
+            consumeResponse (response);
             return (data);
         } catch (Exception ex) {
             logger.error("Error updating folder " + id, ex);
@@ -706,26 +720,26 @@ public class Api {
             logger.debug(response);
             return (response);
         } catch (ClientProtocolException e) {
-        	logger.error("Error updating file " + id + " in folder " + folder, e);
+            logger.error("Error updating file " + id + " in folder " + folder, e);
         } catch (IOException e) {
-        	logger.error("IO error updating file " + id + " in folder " + folder, e);
+            logger.error("IO error updating file " + id + " in folder " + folder, e);
         }
         return ("");
     }
 
 
     public JsonObject getInfoItemJson (String id, String folder) throws UnsupportedEncodingException {
-    	String json = getInfoItemJson (id, folder, null);
-    	JsonParser parser = new JsonParser();
+        String json = getInfoItemJson (id, folder, null);
+        JsonParser parser = new JsonParser();
         JsonObject result = (JsonObject) parser.parse(json);
         return(result);
     }
 
     public String getInfoItemJson(String id, String folder, String version) throws UnsupportedEncodingException {
-    	String params = "files?action=get&id=" + URLEncoder.encode(id, "UTF-8") + "&folder=" + URLEncoder.encode(folder, "UTF-8") + "&version=" + version + "&session=" + session;
-    	if (version == null) {
-    		params = "files?action=get&id=" + URLEncoder.encode(id, "UTF-8") + "&folder=" + URLEncoder.encode(folder, "UTF-8") + "&session=" + session;
-    	}
+        String params = "files?action=get&id=" + URLEncoder.encode(id, "UTF-8") + "&folder=" + URLEncoder.encode(folder, "UTF-8") + "&version=" + version + "&session=" + session;
+        if (version == null) {
+            params = "files?action=get&id=" + URLEncoder.encode(id, "UTF-8") + "&folder=" + URLEncoder.encode(folder, "UTF-8") + "&session=" + session;
+        }
         try {
             CloseableHttpResponse response = getResponse(params);
             HttpEntity ent = response.getEntity();
@@ -856,7 +870,7 @@ public class Api {
     public EncryptedObj getInfoStore(String id, String folder, String version) throws UnsupportedEncodingException {
         String params = "files?action=document&id=" + URLEncoder.encode(id, "UTF-8") + "&folder=" + URLEncoder.encode(folder, "UTF-8") + "&version=" + version + "&session=" + session;
         if (version == null) {
-        	params = "files?action=document&id=" + URLEncoder.encode(id, "UTF-8") + "&folder=" + URLEncoder.encode(folder, "UTF-8") + "&session=" + session;
+            params = "files?action=document&id=" + URLEncoder.encode(id, "UTF-8") + "&folder=" + URLEncoder.encode(folder, "UTF-8") + "&session=" + session;
         }
         long start = System.currentTimeMillis();
         try {
@@ -866,7 +880,7 @@ public class Api {
             EncryptedObj obj = new EncryptedObj(in);
             obj.content_type = ent.getContentType().toString().trim();
             if (obj.content_type.contains(":")) {
-            	obj.content_type = obj.content_type.substring(obj.content_type.indexOf(":") + 1).trim();
+                obj.content_type = obj.content_type.substring(obj.content_type.indexOf(":") + 1).trim();
             }
             response.close();
             logger.info("Retrieved infostore at " + start);
@@ -919,41 +933,41 @@ public class Api {
     }
 
     public Attachment getInlineImage (String url) {
-    	try {
-    		url = java.net.URLDecoder.decode(url, "UTF-8").replace("&amp;","&");
-    		if (url.contains("file?action") || url.contains("image/mail") || url.contains("image/snippet")){
-    			int index = 0;
-    			if (url.contains("file?action")) {
+        try {
+            url = java.net.URLDecoder.decode(url, "UTF-8").replace("&amp;","&");
+            if (url.contains("file?action") || url.contains("image/mail") || url.contains("image/snippet")){
+                int index = 0;
+                if (url.contains("file?action")) {
                     index = url.indexOf("file?action");
                 }
-    			if (url.contains("image/mail")) {
+                if (url.contains("image/mail")) {
                     index = url.indexOf("image/mail");
                 }
                 if (url.contains("image/snippet")) {
                     index = url.indexOf("image/snippet");
                 }
-	        	String params = url.substring(index);
-	            Attachment attach = new Attachment();
-	            CloseableHttpResponse response = getResponse(params);
-	            HttpEntity ent = response.getEntity();
-	            attach.type = ent.getContentType().toString();
-	            if (attach.type.contains(":")) {
-	            	attach.type = attach.type.substring(attach.type.indexOf(":") + 1).trim();
-	            }
-	            org.apache.http.Header[] h = response.getAllHeaders();
-	            for (int i = 0; i < h.length; i++) {
-	         //       System.out.println(h[i].getName() + "  " + h[i].getValue());
-	                if (h[i].getValue().contains("filename")) {
-	                	String filename = h[i].getValue();
-	                	filename = filename.substring(filename.indexOf("filename="));
-	                	attach.filename = filename.replace("filename=", "").replace("\"", "");
-	                }
-	            }
-	            attach.content = EntityUtils.toByteArray(ent);
-	            EntityUtils.consume(ent);
-	            response.close();
-	            return (attach);
-    		}
+                String params = url.substring(index);
+                Attachment attach = new Attachment();
+                CloseableHttpResponse response = getResponse(params);
+                HttpEntity ent = response.getEntity();
+                attach.type = ent.getContentType().toString();
+                if (attach.type.contains(":")) {
+                    attach.type = attach.type.substring(attach.type.indexOf(":") + 1).trim();
+                }
+                org.apache.http.Header[] h = response.getAllHeaders();
+                for (int i = 0; i < h.length; i++) {
+             //       System.out.println(h[i].getName() + "  " + h[i].getValue());
+                    if (h[i].getValue().contains("filename")) {
+                        String filename = h[i].getValue();
+                        filename = filename.substring(filename.indexOf("filename="));
+                        attach.filename = filename.replace("filename=", "").replace("\"", "");
+                    }
+                }
+                attach.content = EntityUtils.toByteArray(ent);
+                EntityUtils.consume(ent);
+                response.close();
+                return (attach);
+            }
         } catch (Exception ex) {
             logger.error("Error getting inline image from " + url, ex);
         }
@@ -974,7 +988,7 @@ public class Api {
     }
 
     public String getConfig (String module) {
-    	String params = "config/" + module + "?session=" + session;
+        String params = "config/" + module + "?session=" + session;
         String dat = null;
         try {
             CloseableHttpResponse response = getResponse(params);
@@ -1014,9 +1028,14 @@ public class Api {
     }
 
     public String getPrimary () {
-        String data = getConfig("mail");
-        JsonObject json = Core.getJSON(data);
-        return (json.get("data").getAsJsonObject().get("defaultaddress").getAsString());
+        try {
+            String data = getConfig("mail");
+            JsonObject json = Core.getJSON(data);
+            return (json.get("data").getAsJsonObject().get("defaultaddress").getAsString());
+        } catch (Exception e) {
+            logger.error("Error getting primary email address ", e);
+            return ("");
+        }
     }
 
     public void deleteItem(String id, int folder) {
@@ -1030,7 +1049,7 @@ public class Api {
             CloseableHttpResponse response = putRequest(params, data);
             HttpEntity ent = response.getEntity();
             String dat = EntityUtils.toString(ent);
-            response.close();
+            consumeResponse (response);
         } catch (Exception e) {
             logger.error("Error deleting item " + id + " in folder " + folder, e);
         }
@@ -1043,42 +1062,42 @@ public class Api {
             CloseableHttpResponse response = putRequest(params, data);
             HttpEntity ent = response.getEntity();
             String dat = EntityUtils.toString(ent);
-            response.close();
+            consumeResponse (response);
         } catch (Exception e) {
             logger.error("Error deleting item " + id + " in folder " + folder, e);
         }
     }
 
     public void handleRef(String msgref, boolean reply, int userid, int cid) {
-    	int i = msgref.lastIndexOf("/");
-    	if (i>0) {
-    		try {
-	    		String defaultDraft = getConfig("mail/folder/drafts");
-	            JsonParser parser = new JsonParser();
-	            JsonObject draft = (JsonObject) parser.parse(defaultDraft);
-	            String id = msgref.substring(i + 1);
-	            String folder = msgref.substring(0, i);
-	            if (reply) {
-	                // mark as reply
-	                setReplied (id, folder);
-	                return;
-	            }
-	    		if (msgref.startsWith(draft.get("data").getAsString()))
-                {
-	    		    if (OxConfiguration.deleteDraft(userid, cid)) {
-	    		        // If draft folder, then delete
-	    		        deleteDraft (id, folder);
-	    		    }
-	    		    return;
+        int i = msgref.lastIndexOf("/");
+        if (i>0) {
+            try {
+                String defaultDraft = getConfig("mail/folder/drafts");
+                JsonParser parser = new JsonParser();
+                JsonObject draft = (JsonObject) parser.parse(defaultDraft);
+                String id = msgref.substring(i + 1);
+                String folder = msgref.substring(0, i);
+                if (reply) {
+                    // mark as reply
+                    setReplied (id, folder);
+                    return;
                 }
-	    		// otherwise, mark as forward
-	    		setForward (id, folder);
+                if (msgref.startsWith(draft.get("data").getAsString()))
+                {
+                    if (OxConfiguration.deleteDraft(userid, cid)) {
+                        // If draft folder, then delete
+                        deleteDraft (id, folder);
+                    }
+                    return;
+                }
+                // otherwise, mark as forward
+                setForward (id, folder);
 
-    		} catch (Exception ex) {
-    			logger.error("Problem getting draft folder ", ex);
-    			return;
-    		}
-    	}
+            } catch (Exception ex) {
+                logger.error("Problem getting draft folder ", ex);
+                return;
+            }
+        }
     }
 
     public void setReplied (String id, String folder) throws UnsupportedEncodingException {
@@ -1096,7 +1115,8 @@ public class Api {
         data.addProperty("flags", flag);
         data.addProperty("value", true);
         try {
-            putRequest(params, data.toString());
+            CloseableHttpResponse response = putRequest(params, data.toString());
+            consumeResponse (response);
         } catch (Exception e) {
             logger.error("Problem marking as read", e);
         }
@@ -1109,22 +1129,23 @@ public class Api {
         data.addProperty("folder", folder);
         data.addProperty("id", id);
         try {
-            putRequest(params, "[" + data.toString() + "]");
+            CloseableHttpResponse response = putRequest(params, "[" + data.toString() + "]");
+            consumeResponse (response);
         } catch (IllegalStateException | IOException e) {
             logger.error("Problem deleting from draft", e);
         }
     }
 
     private String checkCR (String data) {
-    	if (data == null) {
+        if (data == null) {
             return (data);
         }
-    	try {
-    		return (data.replace("\r", "").replace("\n", ""));
-    	} catch (Exception ex) {
-    		logger.error("Error checking header", ex);
-    		return(data);
-    	}
+        try {
+            return (data.replace("\r", "").replace("\n", ""));
+        } catch (Exception ex) {
+            logger.error("Error checking header", ex);
+            return(data);
+        }
     }
 
     /**
