@@ -58,12 +58,10 @@ import java.net.URLEncoder;
 import java.util.Calendar;
 import java.util.Date;
 import java.util.GregorianCalendar;
-
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
-
 import org.apache.commons.codec.binary.Base64;
 import org.apache.commons.lang3.StringEscapeUtils;
 import org.apache.http.HttpResponse;
@@ -80,7 +78,6 @@ import org.xbill.DNS.Record;
 import org.xbill.DNS.TXTRecord;
 import org.xbill.DNS.Type;
 import org.xml.sax.InputSource;
-
 import com.openexchange.guard.config.Config;
 import com.openexchange.guard.database.DbCommand;
 import com.openexchange.guard.database.DbQuery;
@@ -98,11 +95,12 @@ import com.openexchange.guard.util.Core;
  */
 public class InterOx {
 	private static Logger logger = LoggerFactory.getLogger(InterOx.class);
-	
+
     public InterOxInfo getOXLocation(String email) {
         try {
-            if (email.contains("@"))
+            if (email.contains("@")) {
                 email = email.substring(email.indexOf("@") + 1);
+            }
             InterOxInfo info = incache(email);
             if (info != null) {
             	if (compareSqlDate(info.lastcheck)) {  // If checked today, then use, else reload
@@ -118,11 +116,13 @@ public class InterOx {
                 TXTRecord txt = (TXTRecord) records[i];
                 if (txt.getName().toString().toLowerCase().contains("oxguard")) { // make sure this is oxguard record
                     url = txt.rdataToString().replace("\"", "").replace("\\", "");
-                    if (!url.endsWith("/"))
+                    if (!url.endsWith("/")) {
                         url = url + "/";
+                    }
                     // make sure ssl
-                    if (url.startsWith("http:"))
+                    if (url.startsWith("http:")) {
                         url = url.replace("http:", "https:");
+                    }
                     info = saveInCache(email, url);
                     return (info);
                 }
@@ -184,15 +184,16 @@ public class InterOx {
         String from = Core.getStringParameter(request, "from");
         String token = Core.getStringParameter(request, "token");
         String email = Core.getStringParameter(request, "email", true);
-        if (com.openexchange.guard.server.CheckBad.isBad(Core.getIP(request), Config.bad_ip_count)) {
-            sendFail(response, "Temporary lockout");
-            return;
-        }
+
         if (!email.contains("@")) {
             sendFail(response, "Bad email format");
             return;
         }
         try {
+            if (com.openexchange.guard.server.CheckBad.isBad(Core.getIP(request), Config.bad_ip_count)) {
+                sendFail(response, "Temporary lockout");
+                return;
+            }
             boolean create = false;
             if ((from != null) && (token != null)) {
                 InterOxInfo info = getOXLocation(from);
@@ -207,7 +208,9 @@ public class InterOx {
                         	if (!compareSqlDate(info.lastcheck)) {
                         		logger.info("Token not verified today, trying again");
                         		create = verifyToken(info, token);
-                        		if (create) logger.info("OK Verified");
+                        		if (create) {
+                                    logger.info("OK Verified");
+                                }
                         	}
                         }
                     }
@@ -242,12 +245,13 @@ public class InterOx {
         logger.debug("Receiving item");
         String xml = getRequest(request);
         logger.debug("XML: " + xml);
-        if (com.openexchange.guard.server.CheckBad.isBad("r-" + Core.getIP(request), Config.bad_ip_count)) {
-            sendFail(response, "Temporary lockout");
-            return;
-        }
         DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
         try {
+            if (com.openexchange.guard.server.CheckBad.isBad("r-" + Core.getIP(request), Config.bad_ip_count)) {
+                sendFail(response, "Temporary lockout");
+                return;
+            }
+
             DocumentBuilder builder = factory.newDocumentBuilder();
             org.w3c.dom.Document doc = builder.parse(new InputSource(new ByteArrayInputStream(xml.getBytes("utf-8"))));
             doc.getDocumentElement().normalize();
@@ -288,13 +292,16 @@ public class InterOx {
 
         } catch (Exception ex) {
             logger.error("Error saving item", ex);
-            com.openexchange.guard.server.CheckBad.addBad("r-" + Core.getIP(request));
+            try {
+                com.openexchange.guard.server.CheckBad.addBad("r-" + Core.getIP(request));
+            } catch (Exception e) {
+                logger.error("Error adding user to table Bad r-", e);
+            }
             sendFail(response, "Bad request");
         }
-
     }
 
-    public void verifyToken(HttpServletRequest request, HttpServletResponse response) throws GuardMissingParameter {
+    public void verifyToken(HttpServletRequest request, HttpServletResponse response) throws Exception {
         String token = Core.getStringParameter(request, "token", true);
         if (!com.openexchange.guard.server.CheckBad.isBad(Core.getIP(request), Config.bad_ip_count)) {
             if (token.trim().equals(Config.token.trim())) {
@@ -310,17 +317,20 @@ public class InterOx {
         String email = Core.getStringParameter(request, "email", true);
         String itemid = Core.getStringParameter(request, "item", true);
 
-        if (!email.contains("@")) {
-            sendFail(response, "Bad email format");
-            com.openexchange.guard.server.CheckBad.addBad(Core.getIP(request));
-            return;
-        }
-        if (com.openexchange.guard.server.CheckBad.isBad(Core.getIP(request), Config.bad_ip_count)) {
-        	sendFail(response, "Lockout");
-        	return;
-        }
+
         com.openexchange.guard.database.Access acc = new com.openexchange.guard.database.Access();
         try {
+            if (!email.contains("@")) {
+                sendFail(response, "Bad email format");
+                com.openexchange.guard.server.CheckBad.addBad(Core.getIP(request));
+                return;
+            }
+
+            if (com.openexchange.guard.server.CheckBad.isBad(Core.getIP(request), Config.bad_ip_count)) {
+                sendFail(response, "Lockout");
+                return;
+            }
+
             GuardKeys keys = acc.getKeysFromEmail(email);
             if (keys != null) {
 
@@ -334,7 +344,9 @@ public class InterOx {
                 if (db.next()) {
                     int data = db.rs.getInt("Status");
                     if (Config.showStatus == false) {
-                    	if (data > -1) data = -9999;
+                    	if (data > -1) {
+                            data = -9999;
+                        }
                     }
                     sendOK(response, Integer.toString(data));
 
@@ -378,7 +390,9 @@ public class InterOx {
                 db.write(com, keys.userid, keys.contextid);
                 logger.debug("updated: " + db.updated);
                 String resp = "OK";
-                if (db.updated < 1) resp = "No";
+                if (db.updated < 1) {
+                    resp = "No";
+                }
                 db.close();
                 Core.sendOK(response, resp);
                 return (true);
@@ -387,7 +401,12 @@ public class InterOx {
             logger.error("Error deleting share of item " + itemid + " for user " + email, ex);
 
         }
-        com.openexchange.guard.server.CheckBad.addBad(Core.getIP(request));
+        try {
+            com.openexchange.guard.server.CheckBad.addBad(Core.getIP(request));
+        } catch (Exception e) {
+            logger.error("Error adding user to table Bad " +  email, e);
+        }
+
         Core.sendFail(response, "Fail");
         return (false);
     }
@@ -424,7 +443,11 @@ public class InterOx {
             logger.error("Error retracting item " + itemid + " for user " + email, ex);
 
         }
-        com.openexchange.guard.server.CheckBad.addBad(Core.getIP(request));
+        try {
+            com.openexchange.guard.server.CheckBad.addBad(Core.getIP(request));
+        } catch (Exception e) {
+            logger.error("Error adding user to table Bad " +  email, e);
+        }
         return (false);
 
     }
@@ -461,7 +484,7 @@ public class InterOx {
 
     /**
      * Send answer to response stream
-     * 
+     *
      * @param response
      * @param answer String to put in HTML
      */
@@ -498,7 +521,7 @@ public class InterOx {
 
     /**
      * Send request to retract email from remote source
-     * 
+     *
      * @param email
      * @param item
      * @param salt
@@ -524,7 +547,7 @@ public class InterOx {
 
     /**
      * Send delete share to remote source
-     * 
+     *
      * @param email
      * @param item
      * @param salt
@@ -541,7 +564,9 @@ public class InterOx {
             BufferedReader reader = new BufferedReader(new InputStreamReader(response.getEntity().getContent(), "UTF-8"));
             String answer = reader.readLine();
             reader.close();
-            if (answer.contains("OK")) return (true);
+            if (answer.contains("OK")) {
+                return (true);
+            }
             return(false);
         } catch (Exception ex) {
             logger.error("Error while deleting share of item " + item + " for user " + email, ex);
@@ -571,43 +596,6 @@ public class InterOx {
 
     }
 
-    public RecipKey getRemotePublicKey(String email, String from) {
-        InterOxInfo info = getOXLocation(email);
-        if (info == null)
-            return (null);
-        String url = info.url;
-        HttpClient httpClient = new DefaultHttpClient();
-        try {
-            url += "interox?action=getkey&email=" + URLEncoder.encode(email, "ISO-8859-1") + "&from=" + URLEncoder.encode(
-                from,
-                "ISO-8859-1") + "&token=" + URLEncoder.encode(Config.token, "ISO-8859-1");
-            HttpGet request = new HttpGet(url);
-            HttpResponse response = httpClient.execute(request);
-            BufferedReader reader = new BufferedReader(new InputStreamReader(response.getEntity().getContent(), "UTF-8"));
-            StringBuilder sb = new StringBuilder();
-            String line = "";
-            while ((line = reader.readLine()) != null) {
-                sb.append(line);
-            }
-        	reader.close();
-            if (sb.length() < 30) {
-
-                return (null);
-            }
-            if (sb.toString().contains("Unable to create keys")) return(null);
-            RecipKey result = new RecipKey();
-            GuardKeys keys = new GuardKeys();
-            keys.setPublicKeyFrom64String(sb.toString());
-            result.pubkey = keys.getPublic();
-            result.remote = true;
-            return (result);
-        } catch (Exception ex) {
-            logger.error("Error while getting remote public key of " + email + " for " + from, ex);  //might have misunderstood the order here
-            return (null);
-        }
-
-    }
-
     public boolean sendItem(String email, String itemID, String contentKey, long exp, int type, String XML, String salt) throws UnsupportedEncodingException {
         StringBuilder data = new StringBuilder();
         data.append("<item>");
@@ -633,8 +621,9 @@ public class InterOx {
             BufferedReader reader = new BufferedReader(new InputStreamReader(response.getEntity().getContent(), "UTF-8"));
             String answer = reader.readLine();
             reader.close();
-            if (answer.contains("OK"))
+            if (answer.contains("OK")) {
                 return (true);
+            }
             return (false);
 
         } catch (Exception ex) {
@@ -671,7 +660,7 @@ public class InterOx {
         }
         return (null);
     }
-    
+
     /**
      * Check sql date with just date, not time, to current date
      * @param time
