@@ -55,6 +55,7 @@ import java.io.FileInputStream;
 import java.io.IOException;
 import java.util.HashMap;
 import java.util.Iterator;
+import java.util.List;
 import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
 import javax.xml.parsers.DocumentBuilder;
@@ -68,12 +69,11 @@ import org.xml.sax.InputSource;
 import com.google.gson.JsonObject;
 import com.openexchange.guard.config.Config;
 import com.openexchange.guard.config.OxConfiguration;
-import com.openexchange.guard.database.DbCommand;
-import com.openexchange.guard.database.DbQuery;
 import com.openexchange.guard.translate.GetText;
+import com.openexchange.guard.translate.TemplateTransformation;
 
 public class Languages {
-	
+
 	private static Logger logger = LoggerFactory.getLogger(Languages.class);
 
 	public static Map<String, Map<String, String>> avail = new ConcurrentHashMap<String, Map<String, String>>();
@@ -116,13 +116,13 @@ public class Languages {
     }
     /**
      * Get the tranlation of template based on language
-     * 
+     *
      * @param template
      * @param lang Language code, will default if not found
      * @return
      */
-    public static String getTemplateTranslation(String template, String lang) {
-        return (GetText.processTemplate(templ_location + "/" + template, lang));
+    public static String getTemplateTranslation(String template, String lang, List<TemplateTransformation> transformations) {
+        return (GetText.processTemplate(templ_location + "/" + template, lang,transformations));
     }
 
     public static String getTranslation(String text, String lang) {
@@ -133,27 +133,36 @@ public class Languages {
     	int templID = OxConfiguration.getTemplateId(cid, id);
     	return (getTranslation(template, lang, templID));
     }
+
+    public static String getTranslation(String template, String lang, int templId) {
+        return getTranslation(template,lang,templId,null);
+    }
+
     /**
      * Get translation of template, checking for custom based on templId
-     * 
+     *
      * @param template name of template
      * @param lang lanaguage for translation
      * @param templId of custom template if exists, or default provided
      * @return
      */
-    public static String getTranslation(String template, String lang, int templId) {
-    	if (templId == 0) return (getTemplateTranslation(template, lang));
+    public static String getTranslation(String template, String lang, int templId,List<TemplateTransformation> transformations) {
+    	if (templId == 0) {
+            return (getTemplateTranslation(template, lang,transformations));
+        }
         File f = new File(templ_location + "/" + templId + "-" + template);
         if (f.exists()) {
-            return (getTemplateTranslation(templId + "-" + template, lang));
+            return (getTemplateTranslation(templId + "-" + template, lang,transformations));
         } else {
         	logger.warn("no template found for custom template " + template + " id " + templId);
-            return (getTemplateTranslation(template, lang));
+            return (getTemplateTranslation(template, lang,transformations));
         }
     }
 
     public static boolean customTemplateExists(int templId, String template) {
-    	if (templId == 0) return (false);
+    	if (templId == 0) {
+            return (false);
+        }
         File f = new File(templ_location + "/" + templId + "-" + template);
         if (f.exists()) {
             return (true);
@@ -165,7 +174,7 @@ public class Languages {
 
     /**
      * Gets the full country name of a language code in the language specified
-     * 
+     *
      * @param code
      * @param lang Language for the output
      * @return
@@ -175,32 +184,39 @@ public class Languages {
             if (code.length() > 2) {
                 if (avail.containsKey(code.substring(0, 2))) {
                     code = code.substring(0, 2);
-                } else
+                } else {
                     return ("");
-            } else
+                }
+            } else {
                 return ("");
+            }
         }
         Map translations = avail.get(code);
         if (!translations.containsKey(lang)) {
             if (lang.length() > 2) {
                 if (translations.containsKey(lang.substring(0, 2))) {
                     lang = lang.substring(0, 2);
-                } else
+                } else {
                     return ("");
-            } else
+                }
+            } else {
                 return ("");
+            }
         }
         return (String) (translations.get(lang));
     }
 
     // Check if a language is available, if not, return default
     public static String isavail(String code) {
-        if (code == null)
+        if (code == null) {
             return (default_code);
-        if (avail.containsKey(code))
+        }
+        if (avail.containsKey(code)) {
             return (code);
-        if (avail.containsKey(code.substring(0, 2)))
+        }
+        if (avail.containsKey(code.substring(0, 2))) {
             return (code.substring(0, 2));
+        }
         return (default_code);// Not available, so return default
     }
 
@@ -212,10 +228,13 @@ public class Languages {
         while (it.hasNext()) {
             Map.Entry ent = (Map.Entry) it.next();
             Map trans = (Map) ent.getValue();
-            if (!trans.containsKey(lang))
+            if (!trans.containsKey(lang)) {
                 lang = lang.substring(0, 2);
+            }
             if (!trans.containsKey(lang))
+             {
                 lang = default_code; // If we don't have that translation, server default language
+            }
             langJson.addProperty((String) ent.getKey(), (String) trans.get(lang));
         }
         return (langJson);
@@ -266,6 +285,6 @@ public class Languages {
 
         }
     }
-    
+
 
 }
