@@ -205,7 +205,6 @@ public class PGPPrivateKeyHandler {
             //language,version,question,answer,settings?
 
 
-            String recovery = null;
             // Mkae sure the IDs of the new public key are same as the user
             if (verifyID (newkey)) {
                 Long dupl;
@@ -226,6 +225,11 @@ public class PGPPrivateKeyHandler {
                 } else {
                     GuardKeys existing = PGPPublicHandler.getKeyForPGP(userid, cid, dupl, true);
 
+                    if (!existing.verifyPassword(password)) {  // For duplicates, must be same password as original
+                        Core.sendFail(response, "Bad Merge Password");
+                        return;
+                    }
+
                     //////////// HANDLE MERGE/DUPLICATE public keys
                     if ((newkey.pubring = handleDuplicatePublic(newkey, existing, dupl)) == null) {
                         LogAction.setFail();
@@ -241,7 +245,12 @@ public class PGPPrivateKeyHandler {
                     } else {
                         // Update the key
                         newkey = updateOldGuardKey (newkey, existing, password);
-                        acc.updateDuplPGPKey(userid, cid, newkey, recovery, dupl);
+                        if (password != null) {  // Need to recreate recovery if RSAPublic changed
+                            if (Keymanager.checkCreateRecovery(cookie, request)) {
+                                newkey.recovery = Keymanager.createRecovery(newkey, password);
+                            }
+                        }
+                        acc.updateDuplPGPKey(userid, cid, newkey, newkey.recovery, dupl);
                     }
                 }
 
@@ -300,7 +309,7 @@ public class PGPPrivateKeyHandler {
      * @return
 
      */
-    private PGPPublicKeyRing handleDuplicatePublic (GuardKeys gkey, GuardKeys existing, long dupl) {
+    public PGPPublicKeyRing handleDuplicatePublic (GuardKeys gkey, GuardKeys existing, long dupl) {
         try {
         Iterator keys = gkey.pubring.getPublicKeys();
         // get the guardkeys that has the duplicated public key
@@ -340,6 +349,7 @@ public class PGPPrivateKeyHandler {
         if (existing.privKeyNull()) return (newkey);
         try {
             newkey.setPrivate(existing.getDecodedPrivate(password), password);
+            newkey.setPublic(existing.getPublic());
         } catch (Exception ex) {
             logger.error("Problem copying over old Guard Password ", ex);
             return (newkey);
@@ -410,7 +420,7 @@ public class PGPPrivateKeyHandler {
 
         //if key was the current key, then upgrade highest version key to current
         if (iscurrent) {
-        	resetCurrentKey(userid, cid);
+            resetCurrentKey(userid, cid);
         }
         Core.sendOK(response, "OK");
         logger.info("Success deleting private key");
@@ -652,7 +662,7 @@ public class PGPPrivateKeyHandler {
      * @return 0 if not duplicate, otherwise keyid of the duplicate key
      * @throws Exception
      */
-    private long isDuplicate (GuardKeys gkey) throws Exception {
+    public long isDuplicate (GuardKeys gkey) throws Exception {
        List<Long> ids = new ArrayList<Long>();
        Iterator<PGPPublicKey> keys = gkey.pubring.getPublicKeys();
        while (keys.hasNext()) {
