@@ -49,165 +49,175 @@
 
 package com.openexchange.guard.pgp;
 
-import java.io.ByteArrayOutputStream;
-import java.io.IOException;
-import java.io.InputStream;
 import java.security.SignatureException;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Iterator;
 import java.util.List;
 import javax.mail.internet.InternetAddress;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
-import org.apache.commons.codec.binary.Base64;
 import org.apache.commons.fileupload.FileItem;
 import org.apache.commons.fileupload.FileItemFactory;
 import org.apache.commons.fileupload.disk.DiskFileItemFactory;
 import org.apache.commons.fileupload.servlet.ServletFileUpload;
-import org.apache.commons.io.IOUtils;
 import org.bouncycastle.openpgp.PGPException;
-import org.bouncycastle.openpgp.PGPObjectFactory;
 import org.bouncycastle.openpgp.PGPPublicKeyRing;
-import org.bouncycastle.openpgp.PGPUtil;
-import org.bouncycastle.openpgp.operator.bc.BcKeyFingerprintCalculator;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.google.gson.JsonArray;
 import com.google.gson.JsonObject;
 import com.google.gson.JsonPrimitive;
 import com.openexchange.guard.database.Access;
-import com.openexchange.guard.database.DbCommand;
 import com.openexchange.guard.database.DbQuery;
+import com.openexchange.guard.database.ogPGPKeys.OGPGPKey;
+import com.openexchange.guard.database.ogPGPKeys.OGPGPKeysStorage;
+import com.openexchange.guard.database.ogPGPKeys.RestDbOGPGPKeysStorage;
+import com.openexchange.guard.database.pgpKeys.PGPKeys;
+import com.openexchange.guard.database.pgpKeys.PGPKeysStorage;
+import com.openexchange.guard.database.pgpKeys.RestDbPGPKeysStorage;
 import com.openexchange.guard.encr.Crypto;
 import com.openexchange.guard.encr.GuardKeys;
-import com.openexchange.guard.exceptions.GuardMissingParameter;
 import com.openexchange.guard.logging.LogAction;
 import com.openexchange.guard.mailcreator.Attachment;
 import com.openexchange.guard.ox.Api;
+import com.openexchange.guard.pgp.parser.AsciiArmoredKeyParser;
 import com.openexchange.guard.server.OxCookie;
 import com.openexchange.guard.util.Core;
+import com.openexchange.guard.util.ListUtil;
 import com.openexchange.guard.validator.EmailValidator;
 
 public class PGPPublicHandler {
-	private static Logger logger = LoggerFactory.getLogger(PGPPublicHandler.class);
 
-	public void incomingPGPForm(HttpServletRequest request, HttpServletResponse response) throws Exception {
+    public static final int MAX_KEY_FILE_UPLOAD_SIZE =  1000000; /*1 MB*/
+
+    private static Logger logger = LoggerFactory.getLogger(PGPPublicHandler.class);
+
+	public void incomingPGPForm(HttpServletRequest request, HttpServletResponse response, OxCookie cookie) throws Exception {
         FileItemFactory fif = new DiskFileItemFactory();
         ServletFileUpload sfu = new ServletFileUpload(fif);
         int userid = Core.getIntParameter(request, "userid", true);
         int cid = Core.getIntParameter(request, "cid", true);
         LogAction.setUser(userid, cid);
-        List files = sfu.parseRequest(request);
-        String sessionId = Core.getStringParameter(request, "session", true);
-        String ua = request.getHeader("User-Agent");
+        List<FileItem> files = sfu.parseRequest(request);
         String emailRestriction = Core.getStringParameter(request, "emailaddress");  // Optional uid restriction
-        Iterator iterator = files.iterator(); // Iterate through attachments
-        StringBuilder responseSB = new StringBuilder();
-        responseSB.append("[");  // Start response array
-        int count = 0;
+        //Check authentication
+        Api ap = new Api(cookie, request);
+        if (!ap.verifyLogin()) {
+            LogAction.setFail();
+            logger.info("User not logged into UI");
+            Core.sendFail(response, "Must be logged in to UI");
+            return;
+        }
+
+        //Iterate through attachments
+        Iterator<FileItem> iterator = files.iterator();
         while (iterator.hasNext()) {
-            FileItem fi = (FileItem) iterator.next();
-            if (fi.getSize() > 1000000 ) {  // Key sizes over a mb are not allowed
+            FileItem fi = iterator.next();
+
+            //Check the file size
+            if (fi.getSize() > MAX_KEY_FILE_UPLOAD_SIZE) {
                 Core.sendFail(response, "Key size exceeded");
                 return;
             }
-            String name = fi.getFieldName();
-            name = fi.getName();
-            ByteArrayOutputStream out = new ByteArrayOutputStream();
-            InputStream input = fi.getInputStream();
-            IOUtils.copy(input, out); // Copy stream to byte array
-            out.close();
-            input.close();
-            String data = "\r\n" + new String(out.toByteArray());
-            int start = data.indexOf("-----BEGIN PGP PUBLIC");
-            if (start < 0) {
+
+            //Parsing the input stream for public keys rings and using the factory to create them
+            List<PGPPublicKeyRing> publicKeys =
+                PGPPublicKeyRingFactory.create(new AsciiArmoredKeyParser().parse(fi.getInputStream()));
+
+            if(publicKeys.size() > 0) {
+                //If the client provided an email filter we only consider parsed public keys which userids are in the filter
+                String [] emails = emailRestriction == null ? null : emailRestriction.split(",");
+                if(emails != null) {
+                    publicKeys = getKeysForEmail(publicKeys,Arrays.asList(emails));
+                    if(publicKeys.size() == 0) {
+                        logger.debug("User email address not found in the uploaded public keys" );
+                        Core.sendFail(response, "Bad UID");
+                        return;
+                    }
+                }
+
+                // Start response array
+                StringBuilder responseSB = new StringBuilder();
+                responseSB.append("[");
+
+                //Saving all the parsed key-rings for the user
+                int count = 0;
+                for(PGPPublicKeyRing publicKey : publicKeys) {
+                    //Saving each key
+                    if(saveKeyData(publicKey, cid, userid)) {
+                        //Convert the key to JSON and append to the response
+                        JsonArray keydata = PgpHandler.getKeyInfo(publicKey);
+                        responseSB.append(keydata.toString());
+                        //Comma separated, if more than one key
+                        if (count != publicKeys.size() - 1){
+                            responseSB.append(",");
+                        }
+                        count++;
+                    } else {
+                        LogAction.setFail();
+                        logger.warn("Unable to save uploaded public key data");
+                        Core.sendFail(response, "Problem importing key, possible bad data");
+                        return;
+                    }
+                }
+                responseSB.append("]");  // Close the array
+                Core.sendOK(response, responseSB.toString());
+                LogAction.setSuccess();
+            }
+            else {
                 LogAction.setFail();
                 logger.info("Bad data");
-            	Core.sendFail(response, "Bad data");
-            	return;
-            }
-            data = data.substring(start);
-            try {
-            	PGPPublicKeyRing ring = getKeyRing(data);
-            	if (ring == null) {
-            	    LogAction.setFail();
-            	    logger.info("Bad pgp data");
-            		Core.sendFail(response, "Bad pgp data");
-            		return;
-            	}
-            	if (emailRestriction != null) {
-            	    String [] emails = emailRestriction.split(",");
-            	    Iterator<String> uids = ring.getPublicKey().getUserIDs();
-            	    boolean found = false;
-            	    while (uids.hasNext()) {
-            	        String uid = uids.next().toLowerCase();
-            	        for (String em : emails) {
-            	            if (em.contains("@")) { // If email address, check if in userid
-            	                if (uid.contains(em.toLowerCase())) found = true;
-            	            }
-            	        }     
-            	    }
-            	    if (!found) {
-            	        logger.debug("User email address not found in the uploaded public key" );
-            	        Core.sendFail(response, "Bad UID");
-            	        return;
-            	    }
-            	}
-            	if (!saveKeyData(ring, cid, userid, data)) {
-            	    LogAction.setFail();
-            	    logger.warn("Unable to save uploaded public key data");
-            	    Core.sendFail(response, "Problem importing key, possible bad data");
-            	    return;
-            	} else {
-            	    try {
-            	        JsonArray keydata = PgpHandler.getKeyInfo(ring);
-            	        if (count > 0) responseSB.append(",");  // If more than one response, add comma seperator
-            	        responseSB.append(keydata.toString());  // Append json to the response array
-            	        count++;
-            	     //   Core.sendOK(response, keydata.toString());
-            	    } catch (Exception e) {
-            	        logger.error("Problem getting uploaded key data ", e);
-            	    }
-            	}
-            	
-            } catch (Exception e) {
-                LogAction.setFail();
-            	logger.error("Problem importing PGP key ", e);
-            	Core.sendFail(response, "Problem imporing key " + e.getMessage());
-            	return;
+                Core.sendFail(response, "Bad data");
+                return;
             }
         }
-        responseSB.append("]");  // Close the array
-        Core.sendOK(response, responseSB.toString());
-        LogAction.setSuccess();
 	}
-	
-	public static PGPPublicKeyRing getKeyRing (String AscData) throws IOException {
-        // PGPUtil.getDecoderStream() will detect ASCII-armor automatically and decode it,
-        // the PGPObject factory then knows how to read all the data in the encoded stream
-        PGPObjectFactory factory = new PGPObjectFactory(PGPUtil.getDecoderStream(new java.io.ByteArrayInputStream(AscData.getBytes("UTF-8"))), new BcKeyFingerprintCalculator());
-        // these files should really just have one object in them,
-        // and that object should be a PGPPublicKeyRing.
-        Object o = factory.nextObject();
-        if (o instanceof PGPPublicKeyRing) {
-            return (PGPPublicKeyRing) o;
+
+	/**
+	 * Filters a list of public keys for uids
+	 * @param publicKeys the list of keys to filter
+	 * @param emails the filter emails
+	 * @return those keys from publicKeys which uids are in emails
+	 */
+	private List<PGPPublicKeyRing> getKeysForEmail(List<PGPPublicKeyRing> publicKeys, List<String> emails) {
+	    ArrayList<PGPPublicKeyRing> ret = new ArrayList<PGPPublicKeyRing>();
+
+	    for(PGPPublicKeyRing key : publicKeys) {
+	        Iterator<String> uidIterator = key.getPublicKey().getUserIDs();
+
+	        while(uidIterator.hasNext()) {
+	            String uid = uidIterator.next().toLowerCase();
+	            for (String email : emails) {
+                    if (email.contains("@")) { // If email address, check if in userid
+                        if (uid.contains(email.toLowerCase())) {
+                            ret.add(key);
+                        }
+                    }
+                }
+	        }
+	    }
+	    return ret;
+    }
+
+    private boolean saveKeyData (PGPPublicKeyRing ring, int cid, int userid) throws Exception {
+		if (!ring.getPublicKeys().hasNext())
+         {
+            return (false);  // If no public keys, return false
         }
-        throw new IllegalArgumentException("Input text does not contain a PGP Public Key");
-	}
-	
-	public boolean saveKeyData (PGPPublicKeyRing ring, int cid, int userid, String ascData) throws Exception {
-		if (!ring.getPublicKeys().hasNext()) return (false);  // If no public keys, return false
 		JsonArray keydata = PgpHandler.getKeyInfo(ring);
 		JsonArray ids = new JsonArray();
-		String keyhexids = "";
+		List<String> keyhexids = new ArrayList<String>();
 		for (int i = 0; i < keydata.size(); i++) {
 			JsonObject key = keydata.get(i).getAsJsonObject();
 			JsonArray keyids = key.get("ids").getAsJsonArray();
-			keyhexids = keyhexids + key.get("Key").getAsString() + " ";
-			if (keyids.size() > 0) ids = keyids;
+			keyhexids.add(key.get("Key").getAsString());
+			if (keyids.size() > 0) {
+                ids = keyids;
+            }
 		}
-		if (keyhexids.trim().length() < 2) {
-			return(false);
+		if(keyhexids.size() == 0) {
+		    return false;
 		}
 		boolean added = false;
 		for (int j = 0; j < ids.size(); j++) {
@@ -218,25 +228,18 @@ public class PGPPublicHandler {
 				continue;
 			}
 			String email = addr.getAddress();
-			// Update key.  On duplicate, overwrite
-			String command = "INSERT INTO og_pgp_keys (ids, Email, PGPPublic, userid, share_level, cid) VALUES (?, ?, ?, ?, ?, ?) ON DUPLICATE KEY UPDATE PGPPublic = ?, ids = ?";
-			DbCommand com = new DbCommand (command);
-			com.addVariables(keyhexids);
-			com.addVariables(email);
-			com.addVariables(ascData);
-			com.addVariables(userid);
-			com.addVariables(0);
-			com.addVariables(cid);
-			com.addVariables(ascData);
-			com.addVariables(keyhexids);
-			DbQuery db = new DbQuery();
-			db.writeToDB(com, cid);
-			db.close();
+
+			//TODO: Use a DI-Container to resolve this
+			OGPGPKeysStorage ogpgpKeysStorage = new RestDbOGPGPKeysStorage();
+			//Adding the new uploaded key to the storage
+			String asciiData = PGPPublicKeyRingExporter.export(ring);
+			ogpgpKeysStorage.InsertOrUpdate(userid, cid, email, keyhexids, asciiData);
+
 			added = true;
 		}
 		return (added);
 	}
-	
+
 	public void saveKeyAttachment(HttpServletRequest request, HttpServletResponse response, OxCookie ck) throws Exception {
 		int userid = Core.getIntParameter(request, "userid", true);
 		int cid = Core.getIntParameter(request, "cid", true);
@@ -257,7 +260,7 @@ public class PGPPublicHandler {
         if (epass == null) {  // If not encrypted, retrieve plaintext
             Attachment att = ap.getPlainAttachment(emailid, attach, folder);
             data = new String (att.content);
-            
+
         } else {
             // Handle encrypted public key
             String filename = Core.getStringParameter(request, "filename", true);
@@ -270,10 +273,10 @@ public class PGPPublicHandler {
             PgpHandler pgh = new PgpHandler();
             byte[] bytedata = null;
             if (inline) {  // pgp inline attachment
-                bytedata = pgh.decodeInlineAttach(emailid, folder, attach, filename, userid, cid, password, request, ck);                
+                bytedata = pgh.decodeInlineAttach(emailid, folder, attach, filename, userid, cid, password, request, ck);
             } else {  // pgp mime attachment
                 bytedata = pgh.getAttach(request, ck, emailid, folder, userid, cid, filename, password);
-                
+
             }
             if (bytedata == null || bytedata.length < 2) {
                 logger.warn("Unable to decode inline pgp public key attachment");
@@ -282,14 +285,14 @@ public class PGPPublicHandler {
             }
             data = new String(bytedata, "UTF-8");
         }
-        ring = getKeyRing(data);
+        ring = PGPPublicKeyRingFactory.create(data);
         if (ring == null) {
             LogAction.setFail();
             logger.info("Problem reading key data");
         	Core.sendFail(response, "Problem reading key data");
         	return;
         }
-		if (saveKeyData (ring, cid, userid, data)) {
+		if (saveKeyData (ring, cid, userid)) {
 			LogAction.setSuccess();
 			Core.sendOK(response, PgpHandler.getKeyInfo(ring).toString());
 		} else {
@@ -297,15 +300,16 @@ public class PGPPublicHandler {
 		    logger.info("Problem saving key data");
 			Core.sendFail(response, "Problem saving");
 		}
-		
+
 	}
-	
-	
+
+
 	public void getPubKeyDetail (HttpServletRequest request, HttpServletResponse response) throws Exception {
 		int userid = Core.getIntParameter(request, "userid", true);
 		int cid = Core.getIntParameter(request, "cid", true);
 		LogAction.setUser(userid, cid);
 		String ids = Core.getStringParameter(request, "ids", true).trim();
+        String[] idList = ids.trim().split("\\s+");
 		boolean guard = Core.getBooleanParameter(request, "guard");
 		if (guard) {  // If we are to check the Guard tables, do it here
 		    JsonObject guardJson = getGuardPubKeyDetail(ids);
@@ -316,33 +320,33 @@ public class PGPPublicHandler {
 		    }
 		}
 		// Otherwise check uploaded
-		String command = "SELECT PGPPublic, share_level, inline FROM og_pgp_keys WHERE cid = ? and (userid = ? OR share_level > 0) AND ids LIKE ?";
-		DbCommand com = new DbCommand (command);
-		com.addVariables(cid);
-		com.addVariables(userid);
-		com.addVariables(ids + "%");
-		DbQuery db = new DbQuery();
-		db.readFromDB(com, cid);
-		if (db.next()) {
-			String pubkey = db.rs.getString("PGPPublic");
-			PGPPublicKeyRing keyring = getKeyRing(pubkey);
-			JsonArray keydata = PgpHandler.getKeyInfo(keyring);
-			JsonObject retJson = new JsonObject();
-			retJson.add("data", keydata);
-			retJson.add("share", new JsonPrimitive(db.rs.getInt("share_level")));
-			retJson.add("inline", new JsonPrimitive (db.rs.getBit("inline")));
-			if (keydata.size() > 0) {
-				db.close();
-				LogAction.setSuccess();
-				Core.sendOK(response, retJson.toString());
-				return;
-			}
+		//TODO: Use a DI-Container to resolve this
+		RestDbOGPGPKeysStorage ogpgpKeysStorage = new RestDbOGPGPKeysStorage();
+		List<OGPGPKey> ogPGPKeys = ogpgpKeysStorage.getForUserByIds(userid, cid, Arrays.asList(idList));
+		OGPGPKey ogPGPKey = null;
+		//Getting the first key
+		if(ogPGPKeys.size() > 0) {
+		    ogPGPKey = ogPGPKeys.get(0);
 		}
-		db.close();
+
+        if (ogPGPKey != null) {
+            PGPPublicKeyRing keyring = PGPPublicKeyRingFactory.create(ogPGPKey.getPublicPGPAscData());
+            JsonArray keydata = PgpHandler.getKeyInfo(keyring);
+            JsonObject retJson = new JsonObject();
+            retJson.add("data", keydata);
+            retJson.add("share", new JsonPrimitive(ogPGPKey.getShareLevel()));
+            retJson.add("inline", new JsonPrimitive (ogPGPKey.isInline()));
+            if (keydata.size() > 0) {
+                LogAction.setSuccess();
+                Core.sendOK(response, retJson.toString());
+                return;
+            }
+        }
+
 		LogAction.setFail();
 		Core.sendFail(response, "Fail");
 	}
-	
+
 	private JsonObject getGuardPubKeyDetail (String id) throws SignatureException, PGPException {
 	    Access acc = new Access();
 	    String[] ids = id.split(" ");
@@ -357,16 +361,16 @@ public class PGPPublicHandler {
 	            }
 	        }
 	    }
-	    return(null);  
+	    return(null);
 	}
-	
+
 	public void getPubKeyList (HttpServletRequest request, HttpServletResponse response) throws Exception {
 		int userid = Core.getIntParameter(request, "userid", true);
 		int cid = Core.getIntParameter(request, "cid", true);
 		LogAction.setUser(userid, cid);
 		StringBuilder searchlist = new StringBuilder();
 		String emails = Core.getStringParameter(request, "emails");
-		ArrayList emailArray = new ArrayList();
+		ArrayList<String> emailArray = new ArrayList<String>();
 		if (emails != null) {
 		    String [] emailList = emails.split(",");
 		    for (String email : emailList) {
@@ -374,7 +378,9 @@ public class PGPPublicHandler {
 		            if (EmailValidator.validate(email)) {
 		                if (searchlist.length() == 0) {
 		                    searchlist.append("'" + Core.dbformat(email) + "'");
-		                } else searchlist.append(", '" + Core.dbformat(email) + "'");
+		                } else {
+                            searchlist.append(", '" + Core.dbformat(email) + "'");
+                        }
 		                emailArray.add(email);
 		            }
 		        }
@@ -383,32 +389,40 @@ public class PGPPublicHandler {
 		LogAction.setSuccess();
 		Core.sendOK(response, getPubKeyList(userid, cid, searchlist.toString(), emailArray).toString());
 	}
-	
-	public JsonArray getPubKeyList (int userid, int cid, String searchlist, ArrayList emailArray) throws Exception {
-		JsonArray retdata = new JsonArray();
-		String command = "SELECT ids, Email, share_level, userid, inline, (userid = ?) AS owned FROM og_pgp_keys WHERE cid = ? and (userid = ? OR share_level > 0)"; 
-		if (searchlist.length() > 1) {
-		    command += " AND Email IN (" + searchlist + ") ";
+
+	public JsonArray getPubKeyList (int userid, int cid, String searchlist, ArrayList<String> emailArray) throws Exception {
+
+		//TODO: Use a DI-Container or Service locator to inject this
+		OGPGPKeysStorage ogpgpKeysStorage = new RestDbOGPGPKeysStorage();
+		List<OGPGPKey> pgpKeys = (emailArray == null || emailArray.isEmpty()) ?
+		                         ogpgpKeysStorage.getForUser(userid, cid) :
+		                         ogpgpKeysStorage.getForUserByEmail(userid, cid, emailArray,false);
+
+
+		JsonArray ret = new JsonArray();
+		for(OGPGPKey pgpKey : pgpKeys) {
+		    JsonObject jsonKey = new JsonObject();
+		    jsonKey.addProperty("ids", ListUtil.listToString(pgpKey.getKeyIds(), ListUtil.WHITE_SPACE_SEP));
+		    jsonKey.addProperty("email", pgpKey.getEmail());
+            jsonKey.addProperty("share", pgpKey.getShareLevel());
+            jsonKey.addProperty("shared", (userid == pgpKey.getUserId() ? false : true));  // mark if this is a shared key
+            jsonKey.addProperty("inline", pgpKey.isInline());
+            ret.add(jsonKey);
 		}
-		command += "  ORDER BY owned DESC, Email ASC";
-		DbCommand com = new DbCommand (command);
-		com.addVariables(userid);
-		com.addVariables(cid);
-		com.addVariables(userid);
-		DbQuery db = new DbQuery();
-		db.readFromDB(com, cid);
-		retdata = getKeyDataFromDB(db, userid);
+
 		if (emailArray.size() > 0) {
 		    Access acc = new Access();
 		    for (int i = 0; i < emailArray.size(); i++) {
-		        String email = (String) emailArray.get(i);
+		        String email = emailArray.get(i);
 		        GuardKeys gkey = acc.getKeysFromEmail(email);
 		        if (gkey != null) {
 		            JsonArray info = PgpHandler.getKeyInfo(gkey.pubring);
 		            StringBuilder idBuilder = new StringBuilder();
 		            for (int j = 0; j < info.size(); j++) {
 		                JsonObject keyinfo = (JsonObject) info.get(j);
-		                if (j>0) idBuilder.append(" ");
+		                if (j>0) {
+                            idBuilder.append(" ");
+                        }
 		                idBuilder.append(keyinfo.get("Key").getAsString());
 		            }
 		            JsonObject key = new JsonObject();
@@ -417,14 +431,14 @@ public class PGPPublicHandler {
 		            key.addProperty("share", false);
 		            key.addProperty("guard", true);
 		            key.addProperty("inline", gkey.inline);
-		            retdata.add(key);
-		            
+		            ret.add(key);
+
 		        }
 		    }
 		}
-		return(retdata);
+		return(ret);
 	}
-	
+
 	private JsonArray getKeyDataFromDB(DbQuery db, int userid) throws Exception {
 	    JsonArray retdata = new JsonArray();
 	    while (db.next()) {
@@ -439,21 +453,19 @@ public class PGPPublicHandler {
         db.close();
         return(retdata);
 	}
-	
+
 	public void deleteKey (HttpServletRequest request, HttpServletResponse response) throws Exception {
 		int userid = Core.getIntParameter(request, "userid", true);
 		int cid = Core.getIntParameter(request, "cid", true);
 		LogAction.setUser(userid, cid);
 		String ids = Core.getStringParameter(request, "ids", true);
 		try {
-			String command = "DELETE FROM og_pgp_keys WHERE CID = ? AND userid = ? AND ids = ?";
-			DbCommand com = new DbCommand(command);
-			com.addVariables(cid);
-			com.addVariables(userid);
-			com.addVariables(ids.trim());
-			DbQuery db = new DbQuery();
-			db.write(com, userid, cid);
-			db.close();
+
+		    String[] idList = ids.trim().split("\\s+");
+		    //TODO: Using a DI-Container to resolve this
+		    OGPGPKeysStorage ogpgpKeysStorage = new RestDbOGPGPKeysStorage();
+		    ogpgpKeysStorage.Delete(userid, cid, Arrays.asList(idList));
+
 			LogAction.setSuccess();
 			Core.sendOK(response, "OK");
 		} catch (Exception ex) {
@@ -462,24 +474,20 @@ public class PGPPublicHandler {
 			Core.sendFail(response, "Fail");
 		}
 	}
-	
+
 	public void shareKey (HttpServletRequest request, HttpServletResponse response) throws Exception {
 		int userid = Core.getIntParameter(request, "userid", true);
 		int cid = Core.getIntParameter(request, "cid", true);
 		String ids = Core.getStringParameter(request, "ids", true);
+		String[] idList = ids.trim().split("\\s+");
 		LogAction.setUser(userid, cid);
 		String share = Core.getStringParameter(request, "share", true);
 		int sharelevel = share.toLowerCase().trim().equals("true") ? 1 : 0;
 		try {
-			String command = "UPDATE og_pgp_keys SET share_level = ? WHERE cid = ? AND userid = ? AND ids = ?";
-			DbCommand com = new DbCommand(command);
-			com.addVariables(sharelevel);
-			com.addVariables(cid);
-			com.addVariables(userid);
-			com.addVariables(ids.trim());
-			DbQuery db = new DbQuery();
-			db.write(com, userid, cid);
-			db.close();
+		    //TODO: Use a DI-Container for resolving this
+		    RestDbOGPGPKeysStorage ogpgpKeysStorage = new RestDbOGPGPKeysStorage();
+		    ogpgpKeysStorage.UpdateShareLevel(userid, cid, Arrays.asList(idList), sharelevel);
+
 			LogAction.setSuccess();
 			Core.sendOK(response, "OK");
 		} catch (Exception ex) {
@@ -488,24 +496,20 @@ public class PGPPublicHandler {
 			Core.sendFail(response, "Fail");
 		}
 	}
-	
+
 	public void changeInline (HttpServletRequest request, HttpServletResponse response) throws Exception {
 		int userid = Core.getIntParameter(request, "userid", true);
 		int cid = Core.getIntParameter(request, "cid", true);
 		LogAction.setUser(userid, cid);
 		String ids = Core.getStringParameter(request, "ids", true);
+	    String[] idList = ids.trim().split("\\s+");
 		String inlineStr = Core.getStringParameter(request, "inline", true);
-		int isInline = inlineStr.toLowerCase().trim().equals("true") ? 1 : 0;
+		boolean isInline = inlineStr.toLowerCase().trim().equals("true") ? true : false;
 		try {
-			String command = "UPDATE og_pgp_keys SET inline = ? WHERE cid = ? AND userid = ? AND ids = ?";
-			DbCommand com = new DbCommand(command);
-			com.addVariables(isInline);
-			com.addVariables(cid);
-			com.addVariables(userid);
-			com.addVariables(ids.trim());
-			DbQuery db = new DbQuery();
-			db.write(com, userid, cid);
-			db.close();
+		    //TODO: Use a DI-Container to resolve this
+		    RestDbOGPGPKeysStorage ogpgpKeysStorage = new RestDbOGPGPKeysStorage();
+		    ogpgpKeysStorage.UpdateInlineMode(userid, cid, Arrays.asList(idList), isInline);
+
 			LogAction.setSuccess();
 			Core.sendOK(response, "OK");
 		} catch (Exception ex) {
@@ -514,11 +518,11 @@ public class PGPPublicHandler {
 			Core.sendFail(response, "Fail");
 		}
 	}
-	
+
 	public static GuardKeys getKeyForPGP (int id, int cid, long keyid) throws Exception {
 		return (getKeyForPGP (id, cid, keyid, false));
 	}
-	
+
 	/**
 	 * Return the Guard Keys populated with PGP data
 	 * @param id
@@ -529,82 +533,48 @@ public class PGPPublicHandler {
 	 * @throws Exception
 	 */
 	public static GuardKeys getKeyForPGP (int userid, int cid, long keyid, boolean incoming) throws Exception {
-    	String command = "SELECT keyid from PGPKeys WHERE cid = ? and id = ?";
-    	DbCommand com = new DbCommand(command);
-    	com.addVariables(cid);
-    	com.addVariables(keyid);
-    	DbQuery db = new DbQuery();
-    	db.readOG(com);
-    	if (db.next()) {
-    		Access acc = new Access();
-    		GuardKeys keys = acc.getKeys (userid, cid, db.rs.getLong("keyid"), !incoming);  // If incoming, we want all of the keys, not just the current
-    		db.close();
-    		return (keys);
-    	}
-    	db.close();
-    	if (incoming) return(null);
-    	return (getUploadedPublic (userid, cid, Core.PGPKeyId(keyid)));
-    }
-	
-	private static GuardKeys getUploadedPublic (int userid, int cid, String pubid) throws Exception {
-		String command = "SELECT Email, PGPPublic, userid FROM og_pgp_keys WHERE cid = ? AND ids LIKE ? AND (userid = ? OR share_level > 0)";
-		DbCommand com = new DbCommand(command);
-		com.addVariables(cid);
-		com.addVariables("%" + pubid + "%");
-		com.addVariables(userid);
-		DbQuery db = new DbQuery();
-		db.readFromDB(com, cid);
-		GuardKeys keys = null;
-		while (db.next()) {
-		    try {
-    			keys = new GuardKeys ();
-    			keys.email = db.rs.getString("Email");
-    			keys.pubring = getKeyRing(db.rs.getString("PGPPublic"));
-    			keys.contextid = cid;
-    			keys.userid = userid;
-    			int owner = db.rs.getInt("userid");
-                db.close();
-                if (owner == userid) return(keys);  // If this key is owned by the sender, return preferentially
-		    } catch (Exception e) {
-                logger.error("Problem with uploaded key ", e);
-            }
-		}
-		db.close();
-		return (keys);
-	}
-	
-	public static GuardKeys getPGPKeysFromEmail (String email, int userid, int cid) throws Exception {
-	    try {
-    		String command = "SELECT Email, PGPPublic, inline, userid FROM og_pgp_keys WHERE cid = ? AND Email LIKE ? AND (userid = ? OR share_level > 0)";
-    		DbCommand com = new DbCommand(command);
-    		com.addVariables(cid);
-    		com.addVariables(email);
-    		com.addVariables(userid);
-    		DbQuery db = new DbQuery();
-    		db.read(com, userid, cid);
-    		GuardKeys keys = null;
-    		while (db.next()) {
-    		    try {
-        			keys = new GuardKeys ();
-        			keys.email = db.rs.getString("Email");
-        			keys.pubring = getKeyRing(db.rs.getString("PGPPublic"));
-        			keys.inline = db.rs.getBit("inline");
-        			keys.contextid = cid;
-        			keys.userid = userid;
-        			int owner = db.rs.getInt("userid");
-        			db.close();
-        			if (owner == userid) return(keys);  // If this key is owned by the sender, return preferentially
-    		    } catch (Exception e) {
-    		        logger.error("Problem with uploaded key ", e);
-    		        
-    		    }
-    		}
-    		db.close();
-    		// Return any keys found, null otherwise
-    		return (keys);
-	    } catch (Exception ex) {
-	        logger.error("Error retrieving uploaded PGP keys  ", ex);
-	        return(null);
+	    //TODO: Use a DI-Container for resolving
+	    PGPKeysStorage pgpKeysStorage = new RestDbPGPKeysStorage();
+	    PGPKeys keyMapping = pgpKeysStorage.getByKeyIdInContext(cid, keyid);
+	    if(keyMapping != null) {
+           Access acc = new Access();
+           GuardKeys keys = acc.getKeys (userid,
+                                         cid,
+                                         keyMapping.getKeyId(),
+                                         !incoming);  // If incoming, we want all of the keys, not just the current
+            return (keys);
 	    }
+	    if (incoming) {
+            return(null);
+        }
+        return (getUploadedPublic (userid, cid, Core.PGPKeyId(keyid)));
+    }
+
+	private static GuardKeys getUploadedPublic (int userid, int cid, String pubid) throws Exception {
+	    OGPGPKeysStorage ogpgpKeysStorage = new RestDbOGPGPKeysStorage();
+	    List<OGPGPKey> ogPGPKeys = ogpgpKeysStorage.getForUserByIds(userid, cid, Arrays.asList(new String[] {pubid}));
+	    for(OGPGPKey key : ogPGPKeys) {
+	        GuardKeys ret = new GuardKeys();
+	        ret.email = key.getEmail();
+	        ret.pubring = PGPPublicKeyRingFactory.create(key.getPublicPGPAscData());
+	        ret.contextid = cid;
+	        ret.userid = userid;
+	        if(ret.userid == userid) {
+	            return ret;
+	        }
+	    }
+	    return null;
+	}
+
+	public static GuardKeys getPGPKeysFromEmail (String email, int userid, int cid) throws Exception {
+        //TODO: Use a service locator to resolve this
+        OGPGPKeysStorage ogpgpKeysStorage = new RestDbOGPGPKeysStorage();
+        List<OGPGPKey> keys  = ogpgpKeysStorage.getForUserByEmail(userid, cid, Arrays.asList(new String[] {email}),true);
+        for(OGPGPKey key : keys) {
+            if(key.getUserId() == userid) {
+                return GuardKeysFactory.Create(key);
+            }
+        }
+        return null;
 	}
 }
