@@ -190,12 +190,12 @@ public class PGPSender {
     private void updateJsonRecip(JsonObject emailJson, ArrayList<RecipKey> inlineRecip) throws UnsupportedEncodingException {
         JsonObject data = emailJson.get("data").getAsJsonObject();
 
-        JsonObject headers = data.get("headers").getAsJsonObject();
-        JsonArray toRecips = data.get("to").getAsJsonArray();
+        JsonObject headers = data.has("headers") ? data.get("headers").getAsJsonObject() : new JsonObject();
+        JsonArray toRecips = data.has("to") ? data.get("to").getAsJsonArray() : new JsonArray();
         if (toRecips.size() > 0) {
             headers.addProperty("X-To-Recips", getRecipsString(toRecips));
         }
-        JsonArray ccRecips = data.get("cc").getAsJsonArray();
+        JsonArray ccRecips = data.has("cc") ? data.get("cc").getAsJsonArray() : new JsonArray();
         if (ccRecips.size() > 0) {
             headers.addProperty("X-CC-Recips", getRecipsString(ccRecips));
         }
@@ -286,7 +286,7 @@ public class PGPSender {
         } else {
             LogAction.setFail();
             logger.warn("Problem sending email");
-            Core.sendFail(response, "Fail");
+            Core.sendFail(response, resp.replace("fail", ""));
             return;
         }
         Core.sendOK(response, resp);
@@ -495,6 +495,9 @@ public class PGPSender {
                     logger.debug("Saving draft to " + draftFolder);
                 }
                 resp = ap.sendMimeMail(out.toString(), draft ? draftFolder : null);
+                if (Core.checkFail(resp)) {
+                    return ("fail " + Core.getError(resp));
+                }
                 out.close();
                 if (draft) {
                     try {
@@ -521,7 +524,7 @@ public class PGPSender {
             createSavedItem(newMessage, recipients, pin, resp, ap);
         }
         if (failures.size() > 0) {
-            return ("fail some");
+            return ("fail some failed to send");
         }
         return ("OK");
     }
@@ -831,7 +834,7 @@ public class PGPSender {
             JsonObject attach = mailattach.get(i).getAsJsonObject();
             if (attach.has("content_type") || attach.has("type")) {
                 String type = attach.has("content_type") ? attach.get("content_type").getAsString() : attach.get("type").getAsString();
-                switch (type) {
+                switch (type.toLowerCase()) {
                     case "alternative":
                         MimeBodyPart multipart = new MimeBodyPart();
                         String htmlcontent = attach.get("content").getAsString();
