@@ -469,6 +469,7 @@ public class PGPUtils {
 
 	        BcPGPDataEncryptorBuilder builder = new BcPGPDataEncryptorBuilder(PGPEncryptedData.AES_256);
 	        builder.setSecureRandom(new SecureRandom());
+	        builder.setWithIntegrityPacket(true);
 	        PGPEncryptedDataGenerator encryptedDataGenerator = new PGPEncryptedDataGenerator(builder);
 	        for (int i = 0; i < recipients.size(); i++) {
 	            if (recipients.get(i).pgpring != null) {
@@ -522,7 +523,8 @@ public class PGPUtils {
                     }
     			} else {
     				if (!key.isRevoked()) {
-                        return (key);
+    				    if (!PgpKeys.isExpired(key))
+    				        return (key);
                     }
     			}
     		}
@@ -569,7 +571,7 @@ public class PGPUtils {
 	            throw (new NoMasterKeysException("Unable to decode pgp private key"));
 	        }
 
-	        PGPSignatureGenerator       sGen = new PGPSignatureGenerator(new JcaPGPContentSignerBuilder(pgpSec.getPublicKey().getAlgorithm(), PGPUtil.SHA1).setProvider("BC"));
+	        PGPSignatureGenerator       sGen = new PGPSignatureGenerator(new JcaPGPContentSignerBuilder(pgpSec.getPublicKey().getAlgorithm(), PGPUtil.SHA512).setProvider("BC"));
 
 	        sGen.init(PGPSignature.BINARY_DOCUMENT, pgpPrivKey);
 
@@ -584,6 +586,7 @@ public class PGPUtils {
 
 	        BcPGPDataEncryptorBuilder builder = new BcPGPDataEncryptorBuilder(PGPEncryptedData.AES_256);
 	        builder.setSecureRandom(new SecureRandom());
+	        builder.setWithIntegrityPacket(true);
 	        PGPEncryptedDataGenerator encryptedDataGenerator = new PGPEncryptedDataGenerator(builder);
 	        for (int i = 0; i < recipients.size(); i++) {
 	        	BcPublicKeyKeyEncryptionMethodGenerator encKeyGen = new BcPublicKeyKeyEncryptionMethodGenerator(getCryptKey(recipients.get(i).pgpring));
@@ -642,7 +645,7 @@ public class PGPUtils {
         }
 
         int algorithm = key.getPGPSigningKey().getPublicKey().getAlgorithm();
-        PGPSignatureGenerator       sgen = new PGPSignatureGenerator(new JcaPGPContentSignerBuilder(algorithm, PGPUtil.SHA256).setProvider("BC"));
+        PGPSignatureGenerator       sgen = new PGPSignatureGenerator(new JcaPGPContentSignerBuilder(algorithm, PGPUtil.SHA512).setProvider("BC"));
         sgen.init(PGPSignature.BINARY_DOCUMENT, key.getPGPSignKey(password));
 
         BCPGOutputStream bout = new BCPGOutputStream (out);
