@@ -50,6 +50,7 @@
 package com.openexchange.guard.pgp;
 
 import java.io.IOException;
+import java.security.MessageDigest;
 import java.security.SignatureException;
 import java.util.ArrayList;
 import java.util.List;
@@ -102,6 +103,32 @@ public class PgpKeyLookup {
         return(list);
 	}
 
+	/**
+	 * Produce a hex String digest from Email address
+	 * @param fromEmail
+	 * @return
+	 */
+	private static String getHash (String fromEmail) {
+	    if (fromEmail == null) return ("");
+	    try {
+	        StringBuffer hexString = new StringBuffer();
+	        byte[] bytes = fromEmail.toLowerCase().getBytes("UTF-8");
+	        MessageDigest md = MessageDigest.getInstance("MD5");
+	        byte[] digest = md.digest(bytes);
+	        for (int i = 0; i < digest.length; i++) {
+	            if ((0xff & digest[i]) < 0x10) {
+	                hexString.append("0"
+	                        + Integer.toHexString((0xFF & digest[i])));
+	            } else {
+	                hexString.append(Integer.toHexString(0xFF & digest[i]));
+	            }
+	        }
+	        return (hexString.toString());
+	    } catch (Exception e) {
+	        logger.error("Error creating digest of email address for remote query ", e);
+	        return ("");
+	    }
+	}
 	/**
 	 * Get response from PGP Public Key server
 	 * @param url
@@ -110,7 +137,7 @@ public class PgpKeyLookup {
 	 * @throws IllegalStateException
 	 * @throws IOException
 	 */
-    private static String getResponse(String url, String params) throws IllegalStateException, IOException {
+    private static String getResponse(String url, String params, String fromEmail) throws IllegalStateException, IOException {
 
         //CloseableHttpClient httpClient = OxDbConn.httpClient;
         CloseableHttpClient httpClient = HttpConnectionPoolService.getClient();
@@ -121,6 +148,7 @@ public class PgpKeyLookup {
         }
         HttpGet getRequest = new HttpGet(url + port + params);
         getRequest.addHeader("accept", "application/json");
+        getRequest.addHeader("X-UI-INTERNAL-ACCOUNT-ID", getHash(fromEmail));
         getRequest.setHeader("Connection", "close");
         CloseableHttpResponse response = httpClient.execute(getRequest);
         if (response.getStatusLine().getStatusCode() != 200) {
@@ -130,7 +158,11 @@ public class PgpKeyLookup {
         	} catch (Exception e2) {
         		logger.error("unable to close failed connection at PGP getRequest", e2);
         	}
-            throw new RuntimeException("Failed : HTTP error code : " + response.getStatusLine().getStatusCode() + " " + response.getStatusLine().getReasonPhrase());
+        	if (response.getStatusLine().getStatusCode() == 404) {
+        	    logger.debug("No remote pgp key found");
+        	    return ("");
+        	} else
+        	    throw new RuntimeException("Failed : HTTP error code : " + response.getStatusLine().getStatusCode() + " " + response.getStatusLine().getReasonPhrase());
         }
         String data = EntityUtils.toString(response.getEntity(), "UTF-8");
         logger.debug("Data from remote PGP server received");
@@ -198,7 +230,7 @@ public class PgpKeyLookup {
      * @throws SignatureException
      * @throws PGPException
      */
-	private static ArrayList<PGPPublicKeyRing> getPublic (String email) throws IllegalStateException, IOException, SignatureException, PGPException {
+	private static ArrayList<PGPPublicKeyRing> getPublic (String email, String fromEmail) throws IllegalStateException, IOException, SignatureException, PGPException {
 		if (Config.pgpLocations.size() == 0) {
             return (null);
         }
@@ -209,10 +241,10 @@ public class PgpKeyLookup {
 			//String params = "/pks/lookup?op=index&options=mr&search=" + email;
 			String params = "op=index&options=mr&search=" + email;
 			try {
-				String response = getResponse (url, params);
+				String response = getResponse (url, params, fromEmail);
 				ArrayList <String> ids = parseResponse (response, email);
 				for (int j = 0; j < ids.size(); j++) {
-					PGPPublicKeyRing ring = getKeys(ids.get(j), url);
+					PGPPublicKeyRing ring = getKeys(ids.get(j), url, fromEmail);
 					if (ring != null) {
 					    rings.add(ring);
 					}
@@ -228,11 +260,11 @@ public class PgpKeyLookup {
 		return (rings);
 	}
 
-	private static PGPPublicKeyRing getKeys (String id, String url) throws IOException, SignatureException, PGPException {
+	private static PGPPublicKeyRing getKeys (String id, String url, String fromEmail) throws IOException, SignatureException, PGPException {
 	    //String params = "/pks/lookup?op=get&search=0x" + id;
 	    //String params = "/pks/lookup?op=get&options=mr&search=0x" + id;
 	    String params = "op=get&options=mr&search=0x" + id;
-        String output = getResponse (url, params);
+        String output = getResponse (url, params, fromEmail);
         if (output.contains("PUBLIC KEY BLOCK")) {
             output = output.substring(output.indexOf("-----BEGIN"));
             output = output.substring(0, output.lastIndexOf("BLOCK-----") + 10);
@@ -250,7 +282,7 @@ public class PgpKeyLookup {
         return (null);
 	}
 
-	private static ArrayList<PGPPublicKeyRing> getSRVRings (SRVRecord current, String email) {
+	private static ArrayList<PGPPublicKeyRing> getSRVRings (SRVRecord current, String email, String fromEmail) {
 	    ArrayList<PGPPublicKeyRing> rings = new ArrayList<PGPPublicKeyRing>();
 	    int port = current.getPort();
         String target = current.getTarget().toString();
@@ -267,12 +299,12 @@ public class PgpKeyLookup {
         String params = "/pks/lookup?op=index&options=mr&search=" + email;
         String getKeyUrl = url + "/pks/lookup?";
         try {
-            String response = getResponse (url, params);
+            String response = getResponse (url, params, fromEmail);
             ArrayList <String> ids = parseResponse (response, email);
             if (ids.size() > 0) {
                 for (int j = 0; j < ids.size(); j++) {
 
-                    PGPPublicKeyRing ring = getKeys(ids.get(j), getKeyUrl);
+                    PGPPublicKeyRing ring = getKeys(ids.get(j), getKeyUrl, fromEmail);
                     if (ring != null) {
                         rings.add(ring);
                     }
@@ -317,14 +349,14 @@ public class PgpKeyLookup {
 	 * @return
 	 * @throws TextParseException
 	 */
-	private static ArrayList<PGPPublicKeyRing> getPublicFromSrv (String email) throws TextParseException {
+	private static ArrayList<PGPPublicKeyRing> getPublicFromSrv (String email, String fromEmail) throws TextParseException {
 	    ArrayList <SRVRecord> records = getSrvs(email);
 	//    Collections.sort(records);
 	    ArrayList<PGPPublicKeyRing> rings = new ArrayList<PGPPublicKeyRing>();
 	    int current = 0;
 	    SRVRecord nextcheck;
 	    while ((nextcheck = findNext(current, records)) != null) {
-	        rings = getSRVRings(nextcheck, email);
+	        rings = getSRVRings(nextcheck, email, fromEmail);
 	        if (rings != null)
              {
                 return(rings);  // Returns null if there is an error, look for other servers
@@ -359,13 +391,13 @@ public class PgpKeyLookup {
 	 * @return
 	 * @throws Exception
 	 */
-	public static List<PGPPublicKeyRing> lookupKeys (String email) throws Exception {
+	private static List<PGPPublicKeyRing> lookupKeys (String email, String fromEmail) throws Exception {
 
 	    List<PGPPublicKeyRing> rings = checkCache(email);
 	    if (rings.size() > 0) {
             return (rings);
         }
-	    rings = getPublicFromSrv (email); // Check guard servers, or places with srv records
+	    rings = getPublicFromSrv (email, fromEmail); // Check guard servers, or places with srv records
 	    if (rings != null) {
 	        if (rings.size() > 0) {
 	            logger.debug("Remote keys found through SRV");
@@ -374,7 +406,7 @@ public class PgpKeyLookup {
 	        }
 	    }
 
-	    rings = getPublic (email);  // Parse through Configured list of PGP Public key servers
+	    rings = getPublic (email, fromEmail);  // Parse through Configured list of PGP Public key servers
 	    if (rings == null) {
             return(null);
         }
@@ -388,9 +420,9 @@ public class PgpKeyLookup {
 	    return (rings);
 	}
 
-	public static RecipKey getRemoteKeys (String email) {
+	public static RecipKey getRemoteKeys (String email, String fromEmail) {
 	    try {
-	        List<PGPPublicKeyRing> rings = lookupKeys (email);
+	        List<PGPPublicKeyRing> rings = lookupKeys (email, fromEmail);
 	        if (rings == null) {
                 return(null);
             }
