@@ -787,6 +787,21 @@ public class PgpKeys {
         Date now = new Date();
         return (key.getCreationTime().getTime() + (key.getValidSeconds() * 1000) - now.getTime() < 0);
     }
+    
+    /**
+     * Check if all public keys expired
+     * @param ring
+     * @return
+     */
+    public static boolean checkAllExpired (PGPPublicKeyRing ring) {
+        boolean allExpired = true;
+        Iterator <PGPPublicKey> it = ring.getPublicKeys();
+        while (it.hasNext()) {
+            PGPPublicKey key = it.next();
+            allExpired = allExpired && isExpired(key);
+        }
+        return (allExpired);
+    }
 
     private static void markUIDUpdated (GuardKeys key) {
     	try {
