@@ -70,6 +70,8 @@ import com.openexchange.guard.database.GetPubKey;
 import com.openexchange.guard.database.Keymanager;
 import com.openexchange.guard.database.RecipKey;
 import com.openexchange.guard.database.Sharding;
+import com.openexchange.guard.database.mailvelope.MailvelopeStorage;
+import com.openexchange.guard.database.mailvelope.RestDBMailvelopeStorage;
 import com.openexchange.guard.database.ogKeyTable.OGKeyTableStorage;
 import com.openexchange.guard.database.ogKeyTable.RestDbOGKeyTableStorage;
 import com.openexchange.guard.encr.EncrLib;
@@ -652,7 +654,7 @@ public class Auth {
             EncrLib encr = new EncrLib();
             String returndata = "Bad Password";
 
-            if (!keys.verifyPassword(password)) {
+            if (!verifyPassword(keys, keys.userid, keys.contextid, password)) {
                 CheckBad.addBad(username);
                 LogAction.setFail();
                 logger.info("Bad password for " + username);
@@ -748,7 +750,7 @@ public class Auth {
         // Get public RSA keys for password encryption
         String pubkey = Core.getPublicKey();
         if (pubkey != null) {
-        	returnJson.addProperty("pubKey", pubkey);
+        	returnJson.addProperty("pubkey", pubkey);
         }
         int cid = 0;
         try {
@@ -806,6 +808,7 @@ public class Auth {
 	            	}
             	}
             }
+
             if (keys == null) {
                 LogAction.setSuccess();
             	returnJson.addProperty ("auth", "No Key");
