@@ -488,7 +488,7 @@ public class FileHandler {
         } else {
             authData = new UserData(auth, cookie);
         }
-        if (authData.userid == -1) {
+        if (Core.badAuth(authData, userId, cid)) {
             sendFail(response, GetText.gettext("Unable to decode file, bad authorization", lang));
             return;
         }
