@@ -157,11 +157,13 @@ public class Guest {
     	} else {
     		itemid = Core.getStringParameter(request, "email", true);
     	}
+    	int userid = Core.getIntParameter(request, "userid");
+    	int cid = Core.getIntParameter(request, "cid");
     	if (itemid.startsWith("pgp")) {
     		String auth = Core.getStringParameter(request, "auth", true);
             cookie.JSESSIONID = cookie.OxReaderID; // In case person uses both reader and OX main, we need to clear out the previous cookie
             UserData data = new UserData(auth, cookie);
-            if (data.encr_password == null) {
+            if (Core.badAuth(data, userid, cid)) {
                 response.setStatus(HttpServletResponse.SC_BAD_REQUEST);
                 return;
             }
