@@ -76,6 +76,7 @@ import org.apache.commons.fileupload.FileItemFactory;
 import org.apache.commons.fileupload.disk.DiskFileItemFactory;
 import org.apache.commons.fileupload.servlet.ServletFileUpload;
 import org.apache.commons.io.IOUtils;
+import org.bouncycastle.bcpg.ArmoredOutputStream;
 import org.bouncycastle.openpgp.PGPException;
 import org.bouncycastle.util.encoders.Base64;
 import org.slf4j.Logger;
@@ -110,15 +111,18 @@ import com.openexchange.guard.mailcreator.Mail;
 import com.openexchange.guard.ox.Api;
 import com.openexchange.guard.ox.InterOx;
 import com.openexchange.guard.ox.Languages;
+import com.openexchange.guard.pgp.PGPPublicHandler;
+import com.openexchange.guard.pgp.PgpHandler;
+import com.openexchange.guard.pgp.PgpKeyLookup;
 import com.openexchange.guard.server.Settings.permissions;
 import com.openexchange.guard.translate.GetText;
 import com.openexchange.guard.util.Core;
 import com.openexchange.guard.validator.Normalizer;
 
 public class MailHandler {
-	
+
 	private static Logger logger = LoggerFactory.getLogger(MailHandler.class);
-	
+
     OxCookie cookie;
     HttpServletRequest req;
     String sessionId;
@@ -133,7 +137,7 @@ public class MailHandler {
     	Incoming in = new Incoming (cookie, req);
     	in.incomingEmailForm(request, response);
     }
-    
+
     public void incomingDraftForm(HttpServletRequest request, HttpServletResponse response) throws IOException, GuardMissingParameter {
     	Draft in = new Draft (cookie, req);
     	in.incomingEmailForm(request, response);
@@ -144,24 +148,24 @@ public class MailHandler {
     	getter.getEncrEmail(request, response, cookie);
     }
 
-   
+
     public void getEncrAttach(HttpServletRequest request, HttpServletResponse response, com.openexchange.guard.server.OxCookie cookie) throws IOException, GuardMissingParameter {
     	Attachments attachHandle = new Attachments(cookie);
     	attachHandle.getEncrAttach(request, response, cookie);
     }
-    
+
     public void saveDecodedAttach(HttpServletRequest request, HttpServletResponse response, com.openexchange.guard.server.OxCookie cookie) throws IOException, GuardMissingParameter, BadRSAException {
     	Attachments attachHandle = new Attachments(cookie);
     	attachHandle.saveDecodedAttach(request, response, cookie);
     }
-    
-    
- 
+
+
+
 
     /*
      * Get the public key of a recipient
      */
-    public void getRecipKey(HttpServletRequest request, HttpServletResponse response) throws Exception {
+    public void getRecipKey(HttpServletRequest request, HttpServletResponse response, OxCookie ck) throws Exception {
     	String email = Core.getStringParameter(request, "email", true);
     	InternetAddress em = new InternetAddress(email);
     	email = em.getAddress();
@@ -175,7 +179,9 @@ public class MailHandler {
         try {
             int cid = Core.getIntParameter(request, "cid", true);
             LogAction.setUser(senderid, cid);
-            RecipKey recip = acc.getPubKey(email, senderid, cid, from, false, false);
+            Api api = new Api(ck, request);
+            String senderEmail = api.getPrimary();
+            RecipKey recip = acc.getPubKey(email, senderid, cid, senderEmail, false, false);
             JsonObject reply = new JsonObject ();
             reply.addProperty("email", email);
             String keyreply = "unable";
@@ -189,7 +195,7 @@ public class MailHandler {
                     keyreply = recip.pubkey.toString().replace("\r", "").replace("\n", "");
                     reply.addProperty("publicKey", keyreply);
                 } else {// If we don't have a public key, will be guest, or was unable to create
-                	
+
                     if (!recip.guest) {
                     	if (recip.cid > 0) keyreply = "Will be created on first send";
                     }
@@ -213,11 +219,60 @@ public class MailHandler {
     }
 
     /**
-     * Get the read count of an email item. Will query remote services
-     * 
+     * Get PGP Public Key of recipient
+     * If logged into UI, will create key for local recipient
      * @param request
      * @param response
-     * @throws GuardMissingParameter 
+     * @param ck
+     * @throws Exception
+     */
+    public void getPublic(HttpServletRequest request, HttpServletResponse response, OxCookie ck) throws Exception {
+        String email = Core.getStringParameter(request, "email", true);
+        InternetAddress em = new InternetAddress(email);
+        email = em.getAddress();
+        int senderid = Core.getIntParameter(request, "userid");
+        Api ap = new Api(ck, request);
+        boolean authorized = ap.verifyLogin();
+        try {
+            int cid = Core.getIntParameter(request, "cid", true);
+            LogAction.setUser(senderid, cid);
+            GetPubKey getKey = new GetPubKey();
+            RecipKey recip = getKey.getPubKey(email, senderid, cid, ap.getPrimary(), authorized, true);
+            if (recip == null) {  // Try remote lookup here.  Normally not done in the remote lookups
+                Api api = new Api(ck, request);
+                String senderEmail = api.getPrimary();
+                recip = PgpKeyLookup.getRemoteKeys(email, senderEmail);
+            }
+            JsonObject reply = new JsonObject ();
+            if (recip == null) {
+                reply.addProperty("data", "");
+            } else {
+                if (recip.guest) {
+                    reply.addProperty("data", "guest");
+                } else {
+                    if (Core.getBooleanParameter(request, "download")) {
+                        ByteArrayOutputStream out = new ByteArrayOutputStream();
+                        ArmoredOutputStream arm = new ArmoredOutputStream(out);
+                        arm.write(recip.pgpring.getEncoded());
+                        arm.close();
+                        out.close();
+                        reply.addProperty("data", new String(out.toByteArray()));
+                    } else {
+                        reply.add("data", PgpHandler.getKeyInfo(recip.pgpring));
+                    }
+                }
+            }
+            Core.sendJson(response, reply);
+        } catch (Exception ex) {
+
+        }
+    }
+    /**
+     * Get the read count of an email item. Will query remote services
+     *
+     * @param request
+     * @param response
+     * @throws GuardMissingParameter
      */
     public void getReadCount(HttpServletRequest request, HttpServletResponse response) throws GuardMissingParameter {
     	String itemID = Core.getStringParameter(request, "item", true);
@@ -272,14 +327,14 @@ public class MailHandler {
         }
 
     }
-    
- 
+
+
     /**
      * Retract an email item. Will query remote services
-     * 
+     *
      * @param request
      * @param response
-     * @throws GuardMissingParameter 
+     * @throws GuardMissingParameter
      */
     public void retractEmail(HttpServletRequest request, HttpServletResponse response, OxCookie cookie) throws GuardMissingParameter {
     	String itemID = Core.getStringParameter(request, "item", true);
