@@ -57,10 +57,12 @@ import javax.servlet.http.HttpServletResponse;
 import org.slf4j.LoggerFactory;
 import org.slf4j.MDC;
 import ch.qos.logback.classic.Logger;
+import com.google.gson.JsonObject;
 import com.openexchange.guard.config.Config;
 import com.openexchange.guard.encr.OffsiteKeys;
 import com.openexchange.guard.logging.LogAction;
 import com.openexchange.guard.mail.UploadGuest;
+import com.openexchange.guard.mailvelope.PublicKeyImporter;
 import com.openexchange.guard.ox.InterOx;
 import com.openexchange.guard.pgp.PGPAttachments;
 import com.openexchange.guard.pgp.PGPPrivateKeyHandler;
@@ -158,12 +160,20 @@ public class MainServlet extends HttpServlet {
             case ("getkey"):
 
                 try {
-                    mh.getRecipKey(request, response);
+                    mh.getRecipKey(request, response, cookie);
                 } catch (Exception e) {
                 	logger.error("Problem getting key");
                 	handleException (e, request, response);
                 }
                 break;
+            case ("getpublic"):
+                try {
+                    mh.getPublic(request, response, cookie);
+                } catch (Exception e) {
+                    logger.error("Problem getting Public key");
+                    handleException (e, request, response);
+                }
+                break;
             case ("count"):
             	try {
             		mh.getReadCount(request, response);
@@ -442,6 +452,17 @@ public class MainServlet extends HttpServlet {
 	        	}
             }
             break;
+        case "/mailvelope":
+            switch (action){
+                case ("restore"):
+                    try {
+                        MailvelopeService ms = new MailvelopeService();
+                        ms.restoreBackup(request, response, cookie);
+                    }catch (Exception e) {
+                        logger.error("Error restoring mailvelope", e);
+                        handleException (e, request, response);
+                    }
+            }
         case "/demo":
             if (!Config.demo) {
             	logger.error("Attempted demo reset, but not configured for demo.  Add demo:true to config file is needed");
@@ -758,6 +779,19 @@ public class MainServlet extends HttpServlet {
             	try {
             		fh3.encryptUpload(request, response, cookie, false);
             	} catch (Exception e) {
+            	    try {
+            	        if (e.getMessage().contains("Error Code")) {
+            	            JsonObject rj = new JsonObject();
+            	            rj.addProperty("error", e.getMessage());
+            	            rj.addProperty("code", e.getMessage().substring(e.getMessage().indexOf("Error Code")).replace("Error Code", "").trim());
+            	            Core.sendAnswer(response, 200, rj.toString());
+            	            LogAction.setFail();
+            	            logger.error("Error encrypting new file " + e.getMessage());
+            	            return;
+            	        }
+            	    } catch (Exception ex) {
+            	        logger.error("Error uploading file", ex);
+            	    }
             		logger.error("Error encrypting new file", e);
             		handleException (e, request, response);
             	}
@@ -893,6 +927,27 @@ public class MainServlet extends HttpServlet {
                 break;
             }
             break;
+        case "/mailvelope":
+            MailvelopeService ms = new MailvelopeService();
+            switch (action) {
+                case ("backup"):
+                    try {
+                        ms.saveBackup(request, response, cookie);
+                    } catch (Exception e) {
+                        logger.error("Unable to save mailvelope backup " , e);
+                        handleException (e, request, response);
+                    }
+                break;
+                case ("uploadpublic"):
+                    try {
+                        ms.uploadPublicKey(request, response, cookie);
+                    } catch (Exception e) {
+                        logger.error("Unable to handle upload mailvelope public key " , e);
+                        handleException (e, request, response);
+                    }
+                break;
+            }
+            break;
         default:
             response.sendError(404);
             break;
