@@ -104,6 +104,7 @@ import com.openexchange.guard.server.authentication.GuardAuthRoles;
 import com.openexchange.guard.server.connectionPooling.HttpConnectionPoolService;
 import com.openexchange.guard.setup.Upgrader;
 import com.openexchange.guard.storage.s3.S3ClientFactory;
+import com.openexchange.guard.util.Core;
 
 public class Startup {
 
@@ -173,6 +174,9 @@ public class Startup {
 
                 Config.loadMysqlConfigData();
 
+
+
+
                 Upgrader upgrade = new Upgrader();
                 if (upgrade.checkUpgrade()) {
                 	if (!upgrade.doUpgrade()) {
@@ -214,6 +218,14 @@ public class Startup {
                     Runtime.getRuntime().halt(0);
                 }
 
+                if (Config.checkPasswordFile) {
+                    if (!Core.checkPrivate()) {
+                        System.out.println("Bad password file");
+                        logger.error("Bad password file");
+                        Runtime.getRuntime().halt(0);
+                    }
+                }
+               
                 Cache cache = new Cache(); // Initialize the cache
                 Jobs cronJobs = new Jobs(); // Initialize the cron jobs
 
