@@ -87,14 +87,20 @@ class ConnectionPool {
                                       setSocketTimeout(Config.connectionTimeout).
                                       build();
 
-        return cookieHandlingMode == CookieHandlingMode.CookieHandligDissabled ?
-            HttpClients.custom().setDefaultRequestConfig(requestConfig).
-                                 disableCookieManagement().
-                                 disableAutomaticRetries().
-                                 setConnectionManager(cm).build() :
-            HttpClients.custom().setDefaultRequestConfig(requestConfig).
-                                 disableAutomaticRetries().
-                                 setConnectionManager(cm).build();
+        String proxyHost = System.getProperty("http.proxyHost");
+
+        if(cookieHandlingMode == CookieHandlingMode.CookieHandligDissabled) {
+            if (proxyHost == null) {
+                return HttpClients.custom().setDefaultRequestConfig(requestConfig).disableCookieManagement().disableAutomaticRetries().setConnectionManager(cm).build();
+            }
+            return HttpClients.custom().setDefaultRequestConfig(requestConfig).disableCookieManagement().disableAutomaticRetries().useSystemProperties().setConnectionManager(cm).build();
+        }
+
+        if (proxyHost == null) {
+            return HttpClients.custom().setDefaultRequestConfig(requestConfig).disableAutomaticRetries().setConnectionManager(cm).build();
+        }
+        return HttpClients.custom().setDefaultRequestConfig(requestConfig).disableAutomaticRetries().useSystemProperties().setConnectionManager(cm).build();
+
     }
 
     /**
