@@ -27,7 +27,7 @@ public class Repair {
     private static String OGmysqlIP = com.openexchange.guard.config.Config.getMysqlIPOxGuard();
 
     public static String database_name(int db) {
-        return (Config.db_prefix + db);
+        return (Config.getShardBaseName()+ db);
     }
 
 	public static void repairShard () throws Exception {
