@@ -57,14 +57,8 @@ import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
-
-
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-
-import com.openexchange.guard.database.Access;
-import com.openexchange.guard.database.CacheManager;
-
 import com.openexchange.guard.config.Config;
 import com.openexchange.guard.encr.EncryptedObj;
 import com.openexchange.guard.storage.Storage;
@@ -72,7 +66,7 @@ import com.openexchange.guard.storage.Storage;
 
 /**
  * Class for saving encrypted object to and from file system.
- * 
+ *
  * @author benjamin.otterbach@open-xchange.com
  */
 
@@ -81,7 +75,7 @@ public class FileStorage {
 
     /**
      * Write byte array to filename
-     * 
+     *
      * @param filename Full filename of object
      * @param data byte array of data
      * @return
@@ -89,12 +83,12 @@ public class FileStorage {
      */
     public static Boolean writeObj(String directoryPrefix, String ObjId, byte[] data) throws IOException {
     	String directory = Config.getRootFileDirectory() + Storage.DELIMITER + directoryPrefix;
-    	
+
         java.io.File file = new java.io.File(directory);
         if (!file.exists()) {
             file.mkdir();
         }
-    	
+
         Boolean result = false;
         OutputStream output = null;
         try {
@@ -112,7 +106,7 @@ public class FileStorage {
 
     /**
      * Get an object from the cache store.
-     * 
+     *
      * @param directoryPrefix Sub-directory of the files storage location, for example: ext_1_25
      * @param ObjId ID of the file
      * @return EncryptedObj
@@ -134,7 +128,7 @@ public class FileStorage {
             return (null);
         }
     }
-    
+
     public static InputStream getObjectStream(String directoryPrefix, String ObjId) {
         try {
 
@@ -148,19 +142,34 @@ public class FileStorage {
             return (null);
         }
     }
-    
+
+    public static InputStream getObjectStream(String location) {
+        try {
+
+            InputStream in = new FileInputStream(Config.getRootFileDirectory() + Storage.DELIMITER + location);
+            return (in);
+        } catch (FileNotFoundException e) {
+            logger.error("File not found");
+            return (null);
+        } catch (Exception ex) {
+            logger.error("Error getting encrypted file " + location, ex);
+            return (null);
+        }
+    }
+
     /**
      * Delete a file from the cache store. Usually used by the Cache Cleaner.
-     * 
+     *
      * @param location File location including directory prefix. Example: ext_1_25/0ff183ed-097c-4a5a-b534-0198659c775a
      * @throws IOException
      */
     public static void deleteObj(String location) throws IOException {
     	String fileWithPath = Config.getRootFileDirectory() + Storage.DELIMITER + location;
-    	
+
         File file = new File(fileWithPath);
-        if (file.exists())
+        if (file.exists()) {
             file.delete();
+        }
         int i = fileWithPath.lastIndexOf(Storage.DELIMITER);
         File directory = new File(fileWithPath.substring(0, i));
         if (directory.isDirectory()) {
