@@ -49,7 +49,7 @@
 
 /**
  * GetText equivalent.  Loads PO files and parses Templates
- * 
+ *
  */
 
 package com.openexchange.guard.translate;
@@ -66,7 +66,6 @@ import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -74,7 +73,7 @@ import org.slf4j.LoggerFactory;
 public class GetText {
 
 	private static Logger logger = LoggerFactory.getLogger(GetText.class);
-	
+
     private static String def_lang = "en_US";
 
     private static Map<String, Map<String, Translation>> langmaps = new HashMap<String, Map<String, Translation>>();
@@ -84,8 +83,9 @@ public class GetText {
     }
 
     public static void loadFiles(String directory, String domain) {
-        if (domain == null)
+        if (domain == null) {
             domain = "";
+        }
         java.io.File i18folder = new java.io.File(directory);
         java.io.File[] list = i18folder.listFiles();
         for (int i = 0; i < list.length; i++) {
@@ -107,7 +107,9 @@ public class GetText {
 
     public static void loadPOfile(String filename, String language) {
         Map<String, Translation> mapping = new HashMap<String, Translation>();
-    	if (langmaps.containsKey(language)) mapping = langmaps.get(language);
+    	if (langmaps.containsKey(language)) {
+            mapping = langmaps.get(language);
+        }
         Path path = Paths.get(filename);
         java.io.File f = new java.io.File(filename);
         if (!f.exists()) {
@@ -142,6 +144,7 @@ public class GetText {
                         String data = lines.get(i);
                         if (data.contains("msgstr")) {
                         	String transl = getBetweenQuotes(data);
+
                         	while (((i + 1) < lines.size()) && lines.get(i+1).trim().startsWith("\"")) {
                         		i++;
                         		transl = transl + getBetweenQuotes(lines.get(i));
@@ -152,6 +155,7 @@ public class GetText {
                     }
                 }
             }
+
             langmaps.put(language, mapping);
         } catch (Exception ex) {
             logger.error("Error loading .po file " + filename + " for language " + language, ex);
@@ -161,15 +165,16 @@ public class GetText {
     public static String gettext(String msgid, String lang) {
         try {
             Translation trans = langmaps.get(checklang(lang)).get(msgid);
-            if (trans == null)
+            if (trans == null) {
                 return (msgid);
+            }
             return (trans.translation);
         } catch (Exception ex) {
             logger.error("Error translating '" + msgid + "' into " + lang, ex);
             return (msgid);
         }
     }
-    
+
     public static String gettext(String msgid, String lang, String variable) {
     	String translated = gettext(msgid, lang);
     	return (translated.replace("%s", variable));
@@ -177,30 +182,33 @@ public class GetText {
 
     /**
      * Check if we have that language trasnlation. If not, return default
-     * 
+     *
      * @param lang
      * @return
      */
     private static String checklang(String lang) {
-        if ((lang == null) || lang.length() < 2)
+        if ((lang == null) || lang.length() < 2) {
             return (def_lang);
+        }
         if (!langmaps.containsKey(lang)) {
             if (langmaps.containsKey(lang.substring(0, 2))) {// If we don't have the 4 character translation, see if we have 2
                 lang = lang.substring(0, 2);
-            } else
+            }
+            else {
                 lang = def_lang; // If we don't have that language, go to default
+            }
         }
         return (lang);
     }
 
     /**
      * Parse a template. Gettext to be deliniated as <$gt(sometext)>
-     * 
+     *
      * @param filename
      * @param lang
      * @return
      */
-    public static String processTemplate(String filename, String lang) {
+    public static String processTemplate(String filename, String lang, List<TemplateTransformation> transformations) {
         try {
             lang = checklang(lang);
             java.io.File f = new java.io.File(filename);
@@ -209,6 +217,11 @@ public class GetText {
                 return (null);
             }
             String templ = readFile(filename);
+            if(transformations != null) {
+                for(TemplateTransformation transformation : transformations) {
+                    templ = transformation.transformTemplate(templ);
+                }
+            }
             int counter = 0;
             while (templ.contains("<$gettext") && (counter < 1000)) {
                 int i = templ.indexOf("<$gettext(");
@@ -217,6 +230,7 @@ public class GetText {
                     logger.error("Poorly formed template");
                     return (null);
                 }
+
                 String toreplace = templ.substring(i, i + j + 2);
                 String totranslat = removeQuotes(toreplace.replace("<$gettext(", "").replace(")>", ""));
                 templ = templ.replace(toreplace, gettext(totranslat, lang));
