@@ -80,6 +80,26 @@ public class CheckOx {
 
     }
     
+    public static boolean guardInstalled () {
+        String command = "SELECT COUNT(*) as num FROM og_KeyTable";
+        DbCommand com = new DbCommand(command);
+        DbQuery db = new DbQuery();
+        try {
+            db.readOG(com);
+            if (db.next()) {
+                int count = db.rs.getInt("num");
+                if (count > 0) {
+                    db.close();
+                    return (true);
+                }
+            }
+            db.close();
+        } catch (Exception ex) {
+            logger.info("Guard not installed");
+        }
+        return (false);
+    }
+    
     public static void webCheck (HttpServletResponse response) {
     	if (oxAlive()) {
     		Core.sendOK(response, "OK");
