@@ -82,6 +82,7 @@ import com.openexchange.guard.encr.GuardKeys;
 import com.openexchange.guard.exceptions.BadRSAException;
 import com.openexchange.guard.exceptions.GuardMissingParameter;
 import com.openexchange.guard.logging.LogAction;
+import com.openexchange.guard.server.UserData;
 
 
 public class Core {
@@ -701,5 +702,17 @@ public class Core {
         }
         return (ret);
     }
+    
+    // Check if the auth was invalid
+    public static boolean badAuth (UserData data, int id, int cid) {
+        if ((id == 0) && (cid == 0)) {  // If userid and cid are missing, just check password correct.  Used for passing login
+            if ((data.userid == -1) || (data.encr_password == null)) {
+                return true;
+            } else return false;
+        } 
+        
+        if ((data.userid == -1) || (data.encr_password == null) || (data.cid != cid) || (data.userid != id)) return (true);
+        return (false);
+    }
 
 }
